@@ -2,7 +2,7 @@
 Project: Starfighter
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,15 +18,41 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <time.h>
+#include <unistd.h>
 
 #ifdef __APPLE__
 #include "CoreFoundation/CoreFoundation.h"
 #endif
 
+#include "SDL.h"
+
+#ifndef NOSOUND
+#include "SDL_mixer.h"
+#endif
+
+#include "colors.h"
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "cutscene.h"
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "intermission.h"
+#include "renderer.h"
+#include "screen.h"
+#include "title.h"
+#include "weapons.h"
+
 int main(int argc, char **argv)
 {
-	bool cheatAttempt;
+	int cheatAttempt;
 	int cheatCount;
 	int section;
 
@@ -52,7 +78,7 @@ int main(int argc, char **argv)
 
 	engine_init(); // Must do this first!
 
-	cheatAttempt = false;
+	cheatAttempt = 0;
 	cheatCount = 0;
 
 	if (argc > 1)
@@ -74,16 +100,16 @@ int main(int argc, char **argv)
 	for (int i = 1 ; i < argc ; i++)
 	{
 		if (strcmp(argv[i], "-cheat") == 0)
-			cheatAttempt = true;
+			cheatAttempt = 1;
 		if (strcmp(argv[i], "-noaudio") == 0)
 		{
 			printf("No Audio\n");
-			engine.useAudio = false;
+			engine.useAudio = 0;
 		}
 		if (strcmp(argv[i], "-mono") == 0)
 		{
 			printf("Mono sound output\n");
-			engine.useAudio = true;
+			engine.useAudio = 1;
 		}
 		if ((strcmp(argv[i], "humans") == 0) && (cheatCount == 0))
 			cheatCount = 1;
@@ -95,7 +121,7 @@ int main(int argc, char **argv)
 			(strcmp(argv[i], "humansdoitbetter") == 0))
 		{
 			printf("Humans do it better! Cheats enabled.\n");
-			engine.cheat = true;
+			engine.cheat = 1;
 		}
 	}
 
@@ -103,7 +129,7 @@ int main(int argc, char **argv)
 
 	gfx_init();
 	engine_setMode();
-	loadFont();
+	gfx_loadFont();
 
 	if (cheatAttempt && !engine.cheat)
 	{
@@ -120,34 +146,34 @@ int main(int argc, char **argv)
 	gfx_free();
 	audio_loadSounds();
 
-	initWeapons();
+	weapons_init();
 
 	srand(time(NULL));
 
+#ifndef NOSOUND
 	if (engine.useAudio)
 	{
 		Mix_Volume(-1, 100);
 		Mix_VolumeMusic(engine.musicVolume);
 	}
+#endif
 
 	alien_defs_init();
 
 	colors_init();
 
-	showStory();
-
 	// Determine which part of the game we will go to...
 	section = 0;
 
 	game.difficulty = DIFFICULTY_NORMAL;
 	game_init();
 
-	while (true)
+	while (1)
 	{
 		switch (section)
 		{
 			case 0:
-				section = doTitle();
+				section = title_show();
 				break;
 
 			case 1:
