@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2012, 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2012, 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,10 +17,82 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <math.h>
+#include <stdlib.h>
 
-object alien_defs[CD_MAX];
-object aliens[ALIEN_MAX];
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "bullet.h"
+#include "cargo.h"
+#include "collectable.h"
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "info.h"
+#include "mission.h"
+#include "player.h"
+#include "radio.h"
+#include "screen.h"
+#include "ship.h"
+#include "weapons.h"
+
+Object alien_defs[CD_MAX];
+Object aliens[ALIEN_MAX];
+
+static const int nChrisKillMessage = 15;
+static const char *chrisKillMessage[nChrisKillMessage] = {
+	"Take that, robot oppressors!",
+	"Come on, WEAPCO, give me a challenge already!",
+	"Is that all you've got?",
+	"I could kill these robots with my hands tied behind my back!",
+	"And now you're nothing but a pile of scrap metal!",
+	"Who else wants some?!",
+	"Humans do it better!",
+	"A century of AI research is no match for me!",
+	"What's the matter, WEAPCO? Can't keep up?",
+	"I eat robots like you for breakfast!",
+	"Target destroyed!",
+	"Bring it on, WEAPCO!",
+	"I wish the guys back at home could see this!",
+	"How do you like that, WEAPCO?",
+	"Maybe you should change your name to WEEPCO!"
+};
+
+static const int nPhoebeKillMessage = 11;
+static const char *phoebeKillMessage[nPhoebeKillMessage] = {
+	"I got another one!",
+	"Target destroyed!",
+	"One more for me!",
+	"Yes! Did you see that, Chris?",
+	"Hey Chris, remind me to check my kill count later!",
+	"Bring it on, WEAPCO!",
+	"Take that, WEAPCO!",
+	"My kill count is going up!",
+	"Another one bites the dust!",
+	"Yeah! Nothing can stand in our way!",
+	"I got it!"
+};
+
+static const int nUrsulaKillMessage = 14;
+static const char *ursulaKillMessage[nUrsulaKillMessage] = {
+	"Kicked your ass!",
+	"You ain't so tough!",
+	"I was always a better WEAPCO pilot than you!",
+	"Target destroyed!",
+	"That'll teach you!",
+	"Take that, you cruddy robots!",
+	"Is that all you've got?",
+	"Who else wants some?!",
+	"I'm not letting you beat me, Phoebe!",
+	"Bring it on, you mindless drones!",
+	"Oh, I'm sorry, are you getting your metal asses handed to you?",
+	"No one messes with the Lexx family!",
+	"Die, damned WEAPCO drones!",
+	"Don't think you can get away from me!"
+};
 
 /*
 This simply pulls back an alien from the array that is
@@ -125,7 +197,7 @@ void alien_defs_init()
 	alien_defs[CD_FRIGATE].collectChance = 100;
 	alien_defs[CD_FRIGATE].collectType = P_CASH;
 	alien_defs[CD_FRIGATE].collectValue = 500;
-	alien_defs[CD_FRIGATE].flags = FL_WEAPCO;
+	alien_defs[CD_FRIGATE].flags = FL_WEAPCO | FL_NOBANTER;
 
 	alien_defs[CD_FRIGATE_WING1].classDef = CD_FRIGATE_WING1;
 	alien_defs[CD_FRIGATE_WING1].AIType = AI_NORMAL;
@@ -225,7 +297,7 @@ void alien_defs_init()
 	alien_defs[CD_KLINE].collectChance = 0;
 	alien_defs[CD_KLINE].collectType = P_ANYTHING;
 	alien_defs[CD_KLINE].collectValue = 0;
-	alien_defs[CD_KLINE].flags = FL_WEAPCO | FL_ALWAYSFACE | FL_CIRCLES;
+	alien_defs[CD_KLINE].flags = FL_WEAPCO | FL_ALWAYSFACE | FL_CIRCLES | FL_NOBANTER;
 
 	// Aim Fighter
 	alien_defs[CD_AIMFIGHTER].classDef = CD_AIMFIGHTER;
@@ -259,7 +331,7 @@ void alien_defs_init()
 	alien_defs[CD_SLAVETRANSPORT].collectChance = 100;
 	alien_defs[CD_SLAVETRANSPORT].collectType = P_SLAVES;
 	alien_defs[CD_SLAVETRANSPORT].collectValue = 25;
-	alien_defs[CD_SLAVETRANSPORT].flags = FL_WEAPCO | FL_NOFIRE;
+	alien_defs[CD_SLAVETRANSPORT].flags = FL_WEAPCO | FL_NOFIRE | FL_NOBANTER;
 
 	// Good Transport
 	alien_defs[CD_GOODTRANSPORT].classDef = CD_GOODTRANSPORT;
@@ -310,7 +382,7 @@ void alien_defs_init()
 	alien_defs[CD_MINEBOSS].collectChance = 100;
 	alien_defs[CD_MINEBOSS].collectType = P_ANYTHING;
 	alien_defs[CD_MINEBOSS].collectValue = 1000;
-	alien_defs[CD_MINEBOSS].flags = FL_WEAPCO | FL_IMMORTAL;
+	alien_defs[CD_MINEBOSS].flags = FL_WEAPCO | FL_IMMORTAL | FL_NOBANTER;
 
 	alien_defs[CD_BOSS2_WING1].classDef = CD_BOSS2_WING1;
 	alien_defs[CD_BOSS2_WING1].AIType = AI_NORMAL;
@@ -326,7 +398,7 @@ void alien_defs_init()
 	alien_defs[CD_BOSS2_WING1].collectChance = 100;
 	alien_defs[CD_BOSS2_WING1].collectType = P_ANYTHING;
 	alien_defs[CD_BOSS2_WING1].collectValue = 250;
-	alien_defs[CD_BOSS2_WING1].flags = FL_WEAPCO | FL_DAMAGEOWNER;
+	alien_defs[CD_BOSS2_WING1].flags = FL_WEAPCO | FL_DAMAGEOWNER | FL_NOBANTER;
 
 	alien_defs[CD_BOSS2_WING2].classDef = CD_BOSS2_WING2;
 	alien_defs[CD_BOSS2_WING2].AIType = AI_NORMAL;
@@ -342,7 +414,7 @@ void alien_defs_init()
 	alien_defs[CD_BOSS2_WING2].collectChance = 100;
 	alien_defs[CD_BOSS2_WING2].collectType = P_ANYTHING;
 	alien_defs[CD_BOSS2_WING2].collectValue = 250;
-	alien_defs[CD_BOSS2_WING2].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER;
+	alien_defs[CD_BOSS2_WING2].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER | FL_NOBANTER;
 
 	alien_defs[CD_BOSS2_WING3].classDef = CD_BOSS2_WING3;
 	alien_defs[CD_BOSS2_WING3].AIType = AI_NORMAL;
@@ -358,7 +430,7 @@ void alien_defs_init()
 	alien_defs[CD_BOSS2_WING3].collectChance = 100;
 	alien_defs[CD_BOSS2_WING3].collectType = P_ANYTHING;
 	alien_defs[CD_BOSS2_WING3].collectValue = 250;
-	alien_defs[CD_BOSS2_WING3].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER;
+	alien_defs[CD_BOSS2_WING3].flags = FL_WEAPCO | FL_DEPLOYDRONES | FL_DAMAGEOWNER | FL_NOBANTER;
 
 	alien_defs[CD_BOSS2_WING4].classDef = CD_BOSS2_WING4;
 	alien_defs[CD_BOSS2_WING4].AIType = AI_NORMAL;
@@ -374,7 +446,7 @@ void alien_defs_init()
 	alien_defs[CD_BOSS2_WING4].collectChance = 100;
 	alien_defs[CD_BOSS2_WING4].collectType = P_ANYTHING;
 	alien_defs[CD_BOSS2_WING4].collectValue = 250;
-	alien_defs[CD_BOSS2_WING4].flags = FL_WEAPCO | FL_DAMAGEOWNER;
+	alien_defs[CD_BOSS2_WING4].flags = FL_WEAPCO | FL_DAMAGEOWNER | FL_NOBANTER;
 
 	// Drone
 	alien_defs[CD_DRONE].classDef = CD_DRONE;
@@ -391,7 +463,7 @@ void alien_defs_init()
 	alien_defs[CD_DRONE].collectChance = 10;
 	alien_defs[CD_DRONE].collectType = P_SHIELD;
 	alien_defs[CD_DRONE].collectValue = 1;
-	alien_defs[CD_DRONE].flags = FL_WEAPCO;
+	alien_defs[CD_DRONE].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Experimental Fighter
 	alien_defs[CD_CLOAKFIGHTER].classDef = CD_CLOAKFIGHTER;
@@ -425,7 +497,7 @@ void alien_defs_init()
 	alien_defs[CD_EVILURSULA].collectChance = 100;
 	alien_defs[CD_EVILURSULA].collectType = P_ESCAPEPOD;
 	alien_defs[CD_EVILURSULA].collectValue = 1;
-	alien_defs[CD_EVILURSULA].flags = FL_WEAPCO;
+	alien_defs[CD_EVILURSULA].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Mercenary
 	alien_defs[CD_KRASS].classDef = CD_KRASS;
@@ -442,7 +514,7 @@ void alien_defs_init()
 	alien_defs[CD_KRASS].collectChance = 100;
 	alien_defs[CD_KRASS].collectType = P_ANYTHING;
 	alien_defs[CD_KRASS].collectValue = 2250;
-	alien_defs[CD_KRASS].flags = FL_FRIEND | FL_IMMORTAL;
+	alien_defs[CD_KRASS].flags = FL_FRIEND | FL_IMMORTAL | FL_NOBANTER;
 
 	// Executive Transport
 	alien_defs[CD_EXEC].classDef = CD_BOSS;
@@ -459,7 +531,7 @@ void alien_defs_init()
 	alien_defs[CD_EXEC].collectChance = 0;
 	alien_defs[CD_EXEC].collectType = P_ANYTHING;
 	alien_defs[CD_EXEC].collectValue = 2000;
-	alien_defs[CD_EXEC].flags = FL_WEAPCO | FL_NOFIRE;
+	alien_defs[CD_EXEC].flags = FL_WEAPCO | FL_NOFIRE | FL_NOBANTER;
 
 	// Asteroid
 	alien_defs[CD_ASTEROID].classDef = CD_ASTEROID;
@@ -476,7 +548,7 @@ void alien_defs_init()
 	alien_defs[CD_ASTEROID].collectChance = 25;
 	alien_defs[CD_ASTEROID].collectType = P_ORE;
 	alien_defs[CD_ASTEROID].collectValue = 1;
-	alien_defs[CD_ASTEROID].flags = FL_WEAPCO;
+	alien_defs[CD_ASTEROID].flags = FL_WEAPCO | FL_NOBANTER;
 
 	alien_defs[CD_ASTEROID2].classDef = CD_ASTEROID2;
 	alien_defs[CD_ASTEROID2].AIType = AI_WANDER;
@@ -492,7 +564,7 @@ void alien_defs_init()
 	alien_defs[CD_ASTEROID2].collectChance = 25;
 	alien_defs[CD_ASTEROID2].collectType = P_ORE;
 	alien_defs[CD_ASTEROID2].collectValue = 1;
-	alien_defs[CD_ASTEROID2].flags = FL_WEAPCO;
+	alien_defs[CD_ASTEROID2].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Escort
 	alien_defs[CD_ESCORT].classDef = CD_ESCORT;
@@ -560,7 +632,7 @@ void alien_defs_init()
 	alien_defs[CD_PLUTOBOSS].collectChance = 0;
 	alien_defs[CD_PLUTOBOSS].collectType = P_ANYTHING;
 	alien_defs[CD_PLUTOBOSS].collectValue = 1000;
-	alien_defs[CD_PLUTOBOSS].flags = FL_WEAPCO;
+	alien_defs[CD_PLUTOBOSS].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Pluto Boss Barrier
 	alien_defs[CD_BARRIER].classDef = CD_BARRIER;
@@ -577,7 +649,7 @@ void alien_defs_init()
 	alien_defs[CD_BARRIER].collectChance = 100;
 	alien_defs[CD_BARRIER].collectType = P_ANYTHING;
 	alien_defs[CD_BARRIER].collectValue = 25;
-	alien_defs[CD_BARRIER].flags = FL_WEAPCO | FL_NOFIRE;
+	alien_defs[CD_BARRIER].flags = FL_WEAPCO | FL_NOFIRE | FL_NOBANTER;
 
 	// Neptune Boss
 	alien_defs[CD_NEPTUNEBOSS].classDef = CD_NEPTUNEBOSS;
@@ -594,7 +666,7 @@ void alien_defs_init()
 	alien_defs[CD_NEPTUNEBOSS].collectChance = 100;
 	alien_defs[CD_NEPTUNEBOSS].collectType = P_ANYTHING;
 	alien_defs[CD_NEPTUNEBOSS].collectValue = 1000;
-	alien_defs[CD_NEPTUNEBOSS].flags = FL_WEAPCO;
+	alien_defs[CD_NEPTUNEBOSS].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Mobile Shield
 	alien_defs[CD_MOBILESHIELD].classDef = CD_MOBILESHIELD;
@@ -611,7 +683,7 @@ void alien_defs_init()
 	alien_defs[CD_MOBILESHIELD].collectChance = 100;
 	alien_defs[CD_MOBILESHIELD].collectType = P_ANYTHING;
 	alien_defs[CD_MOBILESHIELD].collectValue = 25;
-	alien_defs[CD_MOBILESHIELD].flags = FL_WEAPCO | FL_NOFIRE;
+	alien_defs[CD_MOBILESHIELD].flags = FL_WEAPCO | FL_NOFIRE | FL_NOBANTER;
 
 	// Firefly
 	alien_defs[CD_FIREFLY].classDef = CD_FIREFLY;
@@ -628,7 +700,7 @@ void alien_defs_init()
 	alien_defs[CD_FIREFLY].collectChance = 100;
 	alien_defs[CD_FIREFLY].collectType = P_ANYTHING;
 	alien_defs[CD_FIREFLY].collectValue = 250;
-	alien_defs[CD_FIREFLY].flags = FL_WEAPCO;
+	alien_defs[CD_FIREFLY].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Uranus Boss
 	alien_defs[CD_URANUSBOSS].classDef = CD_URANUSBOSS;
@@ -645,7 +717,7 @@ void alien_defs_init()
 	alien_defs[CD_URANUSBOSS].collectChance = 100;
 	alien_defs[CD_URANUSBOSS].collectType = P_ANYTHING;
 	alien_defs[CD_URANUSBOSS].collectValue = 500;
-	alien_defs[CD_URANUSBOSS].flags = FL_WEAPCO;
+	alien_defs[CD_URANUSBOSS].flags = FL_WEAPCO | FL_NOBANTER;
 
 	// Uranus Boss Wing 1
 	alien_defs[CD_URANUSBOSSWING1].classDef = CD_URANUSBOSSWING1;
@@ -692,7 +764,7 @@ void aliens_init()
 
 	for (int i = 0 ; i < ALIEN_MAX ; i++)
 	{
-		aliens[i].active = false;
+		aliens[i].active = 0;
 		aliens[i].shield = -1;
 		aliens[i].flags = 0;
 	}
@@ -855,8 +927,8 @@ void aliens_init()
 
 			aliens[i].owner = &aliens[i];
 			aliens[i].target = &aliens[i];
-			aliens[i].face = rand() % 2;
-			aliens[i].active = true;
+			aliens[i].face = RANDRANGE(0, 1);
+			aliens[i].active = 1;
 
 			/*
 			we make 1000 attempts to place this enemy since it is required. If after
@@ -864,7 +936,7 @@ void aliens_init()
 			simply isn't going to happen and we will just exit the game. The chances
 			of this happening are very very low!
 			*/
-			while (true)
+			while (1)
 			{
 				placeAttempt++;
 
@@ -887,7 +959,7 @@ void aliens_init()
 
 			if (aliens[i].classDef == CD_CLOAKFIGHTER)
 			{
-				aliens[i].active = false;
+				aliens[i].active = 0;
 				aliens[i].maxShield = aliens[i].shield = 400;
 				aliens[i].flags &= ~FL_RUNSAWAY;
 				aliens[i].speed = 3;
@@ -895,12 +967,12 @@ void aliens_init()
 
 			if ((aliens[i].classDef == CD_MOBILE_RAY) && (i >= ALIEN_BOSS_PART3))
 			{
-				aliens[i].active = false;
+				aliens[i].active = 0;
 			}
 
 			if (aliens[i].classDef == CD_FIREFLY)
 			{
-				aliens[i].active = false;
+				aliens[i].active = 0;
 			}
 
 			if (aliens[i].classDef == CD_BARRIER)
@@ -921,7 +993,7 @@ void aliens_init()
 
 			if (game.area == MISN_JUPITER)
 			{
-				aliens[i].flags = FL_WEAPCO;
+				aliens[i].flags = FL_WEAPCO | FL_NOBANTER;
 				if (i == ALIEN_BOSS)
 					aliens[i].chance[1] = 5;
 			}
@@ -990,7 +1062,7 @@ void aliens_init()
 	}
 }
 
-bool alien_add()
+int alien_add()
 {
 	int index = alien_getFreeIndex();
 
@@ -1112,22 +1184,22 @@ bool alien_add()
 	{
 		if ((game.system == SYSTEM_EYANANTH) && (game.area == MISN_INTERCEPTION))
 		{
-			if ((rand() % 5) == 0)
+			if (CHANCE(1. / 5.))
 				randEnemy = CD_SLAVETRANSPORT;
 		}
 
-		if ((rand() % 6) == 0)
+		if (CHANCE(1. / 6.))
 			randEnemy = CD_TRANSPORTSHIP;
 	}
 
 	delete[] alienArray;
 
 	aliens[index] = alien_defs[randEnemy];
-	aliens[index].active = true;
-	aliens[index].face = rand() % 2;
+	aliens[index].active = 1;
+	aliens[index].face = RANDRANGE(0, 1);
 	aliens[index].owner = &aliens[index]; // Most enemies will own themselves
 	aliens[index].target = &aliens[index];
-	aliens[index].thinktime = (50 + rand() % 50);
+	aliens[index].thinktime = RANDRANGE(50, 100);
 	aliens[index].systemPower = aliens[index].maxShield;
 	aliens[index].deathCounter = 0 - (aliens[index].maxShield * 3);
 	aliens[index].hit = 0;
@@ -1139,9 +1211,9 @@ bool alien_add()
 	{
 		if (alien_place(&aliens[index]))
 			break;
-		aliens[index].active = false;
+		aliens[index].active = 0;
 
-		return false;
+		return 0;
 	}
 
 	if (aliens[index].classDef == CD_CARGOSHIP)
@@ -1161,10 +1233,10 @@ bool alien_add()
 	if (game.area == MISN_ELLESH)
 		aliens[index].flags |= FL_HASMINIMUMSPEED;
 
-	return true;
+	return 1;
 }
 
-void alien_addDrone(object *hostAlien)
+void alien_addDrone(Object *hostAlien)
 {
 	int index = alien_getFreeIndex();
 
@@ -1172,20 +1244,20 @@ void alien_addDrone(object *hostAlien)
 		return;
 
 	aliens[index] = alien_defs[CD_DRONE];
-	aliens[index].active = true;
-	aliens[index].face = rand() % 2;
+	aliens[index].active = 1;
+	aliens[index].face = RANDRANGE(0, 1);
 	aliens[index].owner = &aliens[index]; // Most enemies will own themselves
 	aliens[index].target = &aliens[index];
-	aliens[index].thinktime = (50 + rand() % 50);
+	aliens[index].thinktime = RANDRANGE(50, 100);
 	aliens[index].systemPower = aliens[index].maxShield;
 	aliens[index].deathCounter = 0 - (aliens[index].maxShield * 3);
 	aliens[index].hit = 0;
 
-	aliens[index].x = hostAlien->x + rand() % 50;
-	aliens[index].y = hostAlien->y + rand() % 50;
+	aliens[index].x = hostAlien->x + RANDRANGE(0, 50);
+	aliens[index].y = hostAlien->y + RANDRANGE(0, 50);
 }
 
-void alien_addSmallAsteroid(object *hostAlien)
+void alien_addSmallAsteroid(Object *hostAlien)
 {
 	if (engine.missionCompleteTimer != 0)
 		return;
@@ -1194,7 +1266,7 @@ void alien_addSmallAsteroid(object *hostAlien)
 	int debris = RANDRANGE(1, 10);
 
 	for (int i = 0 ; i < debris ; i++)
-		bullet_add(&weapon[W_ROCKETS], hostAlien, 0, 0);
+		bullet_add(&weapons[W_ROCKETS], hostAlien, 0, 0);
 
 	for (int i = 0 ; i <= ALIEN_NORMAL_LAST ; i++)
 		if (!aliens[i].active)
@@ -1203,7 +1275,7 @@ void alien_addSmallAsteroid(object *hostAlien)
 	if (index == -1)
 		return;
 
-	if ((rand() % 10) > 3)
+	if (CHANCE(3 / 5.))
 	{
 		aliens[index] = alien_defs[CD_ASTEROID2];
 		aliens[index].imageIndex[0] = RANDRANGE(SS_ASTEROID_SMALL, SS_ASTEROID_SMALL_L);
@@ -1225,7 +1297,7 @@ void alien_addSmallAsteroid(object *hostAlien)
 
 	aliens[index].x = hostAlien->x;
 	aliens[index].y = hostAlien->y;
-	aliens[index].active = true;
+	aliens[index].active = 1;
 }
 
 void alien_addFriendly(int type)
@@ -1237,7 +1309,7 @@ void alien_addFriendly(int type)
 
 	aliens[type].owner = &aliens[type];
 	aliens[type].target = &aliens[type];
-	aliens[type].active = true;
+	aliens[type].active = 1;
 	aliens[type].x = RANDRANGE((screen->w / 2) - 150, (screen->w / 2) + 150);
 	aliens[type].y = RANDRANGE((screen->h / 2) - 150, (screen->h / 2) + 150);
 
@@ -1252,14 +1324,14 @@ void alien_addFriendly(int type)
 		aliens[type].flags |= FL_IMMORTAL;
 }
 
-bool alien_place(object *alien)
+int alien_place(Object *alien)
 {
-	if (rand() % 2 == 0)
+	if (CHANCE(0.5))
 		alien->x = RANDRANGE(screen->w, screen->w * 2);
 	else
 		alien->x = RANDRANGE(-screen->w, 0);
 
-	if (rand() % 2 == 0)
+	if (CHANCE(0.5))
 		alien->y = RANDRANGE(screen->h, screen->h * 2);
 	else
 		alien->y = RANDRANGE(-screen->h, 0);
@@ -1275,14 +1347,14 @@ bool alien_place(object *alien)
 		if ((aliens[i].owner != alien) && (aliens[i].shield > 0))
 		{
 			if (ship_collision(alien, &aliens[i]))
-				return false;
+				return 0;
 		}
 	}
 
-	return true;
+	return 1;
 }
 
-void alien_setAI(object *alien)
+void alien_setAI(Object *alien)
 {
 	int i;
 	float tx;
@@ -1304,7 +1376,7 @@ void alien_setAI(object *alien)
 		}
 	}
 
-	i = rand() % 10;
+	i = RANDRANGE(0, 9);
 	tx = alien->target->x;
 	ty = alien->target->y;
 
@@ -1345,8 +1417,8 @@ void alien_setAI(object *alien)
 	if (i <= chase)
 	{
 		// Chase the target
-		alien->dx = ((alien->x - tx) / ((300 / alien->speed) + rand() % 100));
-		alien->dy = ((alien->y - ty) / ((300 / alien->speed) + rand() % 100));
+		alien->dx = ((alien->x - tx) / ((300 / alien->speed) + RANDRANGE(0, 100)));
+		alien->dy = ((alien->y - ty) / ((300 / alien->speed) + RANDRANGE(0, 100)));
 		return;
 	}
 	else if ((i >= point) && (i <= stop))
@@ -1354,8 +1426,8 @@ void alien_setAI(object *alien)
 		// Fly to a random point around the target
 		tx += RANDRANGE(-area, area);
 		ty += RANDRANGE(-area, area);
-		alien->dx = ((alien->x - tx) / ((300 / alien->speed) + rand() % 100));
-		alien->dy = ((alien->y - ty) / ((300 / alien->speed) + rand() % 100));
+		alien->dx = ((alien->x - tx) / ((300 / alien->speed) + RANDRANGE(0, 100)));
+		alien->dy = ((alien->y - ty) / ((300 / alien->speed) + RANDRANGE(0, 100)));
 		return;
 	}
 	else
@@ -1367,11 +1439,11 @@ void alien_setAI(object *alien)
 	}
 }
 
-void alien_setKlineAttackMethod(object *alien)
+void alien_setKlineAttackMethod(Object *alien)
 {
 	if (alien->shield <= 500)
 	{
-		setRadioMessage(FS_KLINE, "ENOUGH!! THIS ENDS NOW!!!", 1);
+		radio_setMessage(FS_KLINE, "ENOUGH! THIS ENDS NOW!", 1);
 		alien->weaponType[0] = W_AIMED_SHOT;
 		alien->weaponType[1] = W_MICRO_HOMING_MISSILES;
 		alien->flags |= FL_CANCLOAK;
@@ -1380,7 +1452,7 @@ void alien_setKlineAttackMethod(object *alien)
 	}
 	else if (alien->shield <= 1000)
 	{
-		setRadioMessage(FS_KLINE, "Your ability to stay alive irritates me!! Try dodging some of these!!", 1);
+		radio_setMessage(FS_KLINE, "Your ability to stay alive irritates me! Try dodging some of these!", 1);
 		if (game.difficulty == DIFFICULTY_ORIGINAL)
 		{
 			alien->weaponType[0] = W_DIRSHOCKMISSILE;
@@ -1392,7 +1464,7 @@ void alien_setKlineAttackMethod(object *alien)
 	}
 	else
 	{
-		setRadioMessage(FS_KLINE, "Very good, Bainfield. Now let's get a little more serious...", 1);
+		radio_setMessage(FS_KLINE, "Very good, Bainfield. Now let's get a little more serious...", 1);
 		alien->weaponType[0] = W_SPREADSHOT;
 		alien->chance[1] = 40;
 	}
@@ -1401,7 +1473,7 @@ void alien_setKlineAttackMethod(object *alien)
 /*
 This AI is exclusively for Kline.
 */
-void alien_setKlineAI(object *alien)
+void alien_setKlineAI(Object *alien)
 {
 	// Weapon type change
 	if (CHANCE(1. / 3.))
@@ -1410,34 +1482,34 @@ void alien_setKlineAI(object *alien)
 		{
 			alien->flags &= ~FL_AIMS;
 
-			switch(rand() % 2)
+			if (CHANCE(0.5))
 			{
-				case 0:
-					if ((game.area != MISN_VENUS) || (alien->shield > 1500))
-						alien->weaponType[0] = W_TRIPLE_SHOT;
-					else
-						alien->weaponType[0] = W_SPREADSHOT;
-					break;
-				case 1:
-					alien->weaponType[0] = W_AIMED_SHOT;
-					alien->flags |= FL_AIMS;
-					break;
+				if ((game.area != MISN_VENUS) || (alien->shield > 1500))
+					alien->weaponType[0] = W_TRIPLE_SHOT;
+				else
+					alien->weaponType[0] = W_SPREADSHOT;
+			}
+			else
+			{
+				alien->weaponType[0] = W_AIMED_SHOT;
+				alien->flags |= FL_AIMS;
+
 			}
 		}
 	}
 
 	alien->flags &= ~(FL_CIRCLES | FL_CONTINUOUS_FIRE | FL_DROPMINES);
 
-	switch(rand() % 10)
+	switch(RANDRANGE(0, 9))
 	{
 		case 0:
 			if ((alien->weaponType[0] != W_DIRSHOCKMISSILE) &&
 					(alien->weaponType[1] != W_MICRO_HOMING_MISSILES))
 				alien->flags |= FL_CONTINUOUS_FIRE;
 			alien->dx = ((alien->x - alien->target->x) /
-				((300 / alien->speed)  + rand() % 100));
+				((300 / alien->speed)  + RANDRANGE(0, 100)));
 			alien->dy = ((alien->y - alien->target->y) /
-				((300 / alien->speed)  + rand() % 100));
+				((300 / alien->speed)  + RANDRANGE(0, 100)));
 			break;
 		case 1:
 		case 2:
@@ -1461,15 +1533,14 @@ void alien_setKlineAI(object *alien)
 "Looks" for an enemy by picking a randomly active enemy and using them
 as a target. If the target is too far away, it will be ignored.
 */
-void alien_searchForTarget(object *alien)
+void alien_searchForTarget(Object *alien)
 {
 	int i;
+	Object *targetEnemy;
 
 	if (alien->flags & FL_WEAPCO)
 	{
-		i = (rand() % 10);
-
-		if (i == 0)
+		if (CHANCE(1 / 10.))
 		{
 			alien->target = &player;
 			return;
@@ -1477,8 +1548,7 @@ void alien_searchForTarget(object *alien)
 	}
 
 	i = rand() % ALIEN_MAX;
-
-	object *targetEnemy = &aliens[i];
+	targetEnemy = &aliens[i];
 
 	// Tell Sid not to attack craft that are already disabled or can
 	// return fire. This will save him from messing about (unless we're on the last mission)
@@ -1524,7 +1594,7 @@ void alien_searchForTarget(object *alien)
 /*
 Do various checks to see if the alien can fire at the target.
 */
-int alien_checkTarget(object *alien)
+int alien_checkTarget(Object *alien)
 {
 	// No target
 	if (alien->target == alien)
@@ -1565,7 +1635,7 @@ int alien_checkTarget(object *alien)
 Currently only used for the allies. Whilst flying around, the allies will fire on
 any enemy craft that enter their line of sight.
 */
-int alien_enemiesInFront(object *alien)
+int alien_enemiesInFront(Object *alien)
 {
 	for (int i = 0 ; i < ALIEN_MAX ; i++)
 	{
@@ -1586,14 +1656,14 @@ int alien_enemiesInFront(object *alien)
 	return 0;
 }
 
-void alien_move(object *alien)
+void alien_move(Object *alien)
 {
-	bool checkCollisions;
+	int checkCollisions;
 
 	if ((alien->flags & FL_LEAVESECTOR) || (alien->shield < 1))
-		checkCollisions = false;
+		checkCollisions = 0;
 	else
-		checkCollisions = true;
+		checkCollisions = 1;
 
 	if (alien->owner == alien)
 	{
@@ -1688,8 +1758,10 @@ void alien_move(object *alien)
 /*
 Fill in later...
 */
-void alien_destroy(object *alien, object *attacker)
+void alien_destroy(Object *alien, Object *attacker)
 {
+	int r;
+
 	audio_playSound(SFX_EXPLOSION, alien->x, alien->y);
 
 	if (alien->flags & FL_FRIEND)
@@ -1703,9 +1775,9 @@ void alien_destroy(object *alien, object *attacker)
 		if (game.area != MISN_NEROD)
 		{
 			if ((alien->classDef == CD_PHOEBE) || (alien->classDef == CD_URSULA))
-				setInfoLine(">> Ally has ejected! <<\n", FONT_RED);
+				info_setLine(">> Ally has ejected! <<\n", FONT_RED);
 			else
-				setInfoLine(">> Friendly craft has been destroyed! <<\n", FONT_RED);
+				info_setLine(">> Friendly craft has been destroyed! <<\n", FONT_RED);
 		}
 	}
 
@@ -1714,45 +1786,55 @@ void alien_destroy(object *alien, object *attacker)
 		if (attacker == &player)
 		{
 			game.totalKills++;
+			if (CHANCE(1 / 16.) && (alien->flags & FL_WEAPCO) &&
+				(!(alien->flags & FL_NOBANTER)))
+			{
+				r = rand() % nChrisKillMessage;
+				radio_setMessage(FS_CHRIS, chrisKillMessage[r], 0);
+			}
 		}
 		else if (attacker->classDef == CD_PHOEBE)
 		{
 			game.wingMate1Kills++;
+			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO) &&
+				(!(alien->flags & FL_NOBANTER)))
+			{
+				r = rand() % nPhoebeKillMessage;
+				radio_setMessage(FS_PHOEBE, phoebeKillMessage[r], 0);
+			}
 		}
 		else if (attacker->classDef == CD_URSULA)
 		{
 			game.wingMate2Kills++;
+			if (CHANCE(1 / 8.) && (alien-> flags & FL_WEAPCO) &&
+				(!(alien->flags & FL_NOBANTER)))
+			{
+				r = rand() % nUrsulaKillMessage;
+				radio_setMessage(FS_URSULA, ursulaKillMessage[r], 0);
+			}
 		}
 		else
 		{
 			game.totalOtherKills++;
 		}
-
-		if ((attacker->classDef == CD_PHOEBE) || (attacker->classDef == CD_URSULA))
-		{
-			if ((rand() % 8) == 0)
-			{
-				getKillMessage(attacker);
-			}
-		}
 	}
 
-	updateMissionRequirements(M_DESTROY_TARGET_TYPE, alien->classDef, 1);
-	updateMissionRequirements(M_PROTECT_TARGET, alien->classDef, 1);
+	mission_updateRequirements(M_DESTROY_TARGET_TYPE, alien->classDef, 1);
+	mission_updateRequirements(M_PROTECT_TARGET, alien->classDef, 1);
 
-	if (rand() % 100 <= alien->collectChance)
+	if (CHANCE(alien->collectChance / 100.))
 	{
 		int value;
 
-		if ((rand() % 10) == 0)
+		if (CHANCE(1 / 10.))
 			alien->collectValue *= 2;
 
 		while (alien->collectValue > 0)
 		{
-			value = (10 + (rand() % alien->collectValue));
+			value = RANDRANGE(10, 100);
 			if (value > alien->collectValue)
 				value = alien->collectValue;
-			collectable_add(alien->x, alien->y, alien->collectType, value, 600);
+			collectable_add(alien->x, alien->y, alien->collectType, value, MAX(600, 2 * alien->collectValue));
 			alien->collectValue -= value;
 		}
 	}
@@ -1764,17 +1846,17 @@ void alien_destroy(object *alien, object *attacker)
 	}
 
 	if ((alien->classDef == CD_KRASS) && (attacker == &player))
-		setRadioMessage(FS_CHRIS, "The name's CHRIS, old-timer.", 1);
+		radio_setMessage(FS_CHRIS, "The name's CHRIS, old-timer.", 1);
 
 	if (alien->classDef == CD_KLINE)
 	{
-		setRadioMessage(FS_KLINE, "It was an honor... to have fought you...", 1);
+		radio_setMessage(FS_KLINE, "It was an honor... to have fought you...", 1);
 		alien->dx = alien->dy = 0;
 		alien->shield = -150;
 	}
 }
 
-void alien_hurt(object *alien, object *attacker, int damage, bool ion)
+void alien_hurt(Object *alien, Object *attacker, int damage, int ion)
 {
 	double run_chance;
 
@@ -1793,22 +1875,22 @@ void alien_hurt(object *alien, object *attacker, int damage, bool ion)
 	{
 		if (game.area == MISN_ELAMALE)
 		{
-			if ((alien->shield <= alien->maxShield - 500) &&
+			if ((alien->shield <= alien->maxShield - ((game.difficulty != DIFFICULTY_ORIGINAL) ? 500 : 750)) &&
 				!(alien->flags & FL_LEAVESECTOR))
 			{
 				alien->flags |= FL_LEAVESECTOR;
 				alien->flags &= ~FL_CIRCLES;
-				setRadioMessage(FS_KLINE, "Seems I underestimated you, Bainfield. We'll meet again!", 1);
+				radio_setMessage(FS_KLINE, "Seems I underestimated you, Bainfield. We'll meet again!", 1);
 			}
 		}
 		else if (game.area == MISN_EARTH)
 		{
-			if ((alien->shield <= alien->maxShield - 750) &&
+			if ((alien->shield <= alien->maxShield - ((game.difficulty != DIFFICULTY_ORIGINAL) ? 750 : 500)) &&
 				!(alien->flags & FL_LEAVESECTOR))
 			{
 				alien->flags |= FL_LEAVESECTOR;
 				alien->flags &= ~FL_CIRCLES;
-				setRadioMessage(FS_SID, "Chris, Kethlan is getting away!", 1);
+				radio_setMessage(FS_SID, "Chris, Kethlan is getting away!", 1);
 			}
 		}
 		else if (game.area == MISN_VENUS)
@@ -1853,7 +1935,7 @@ void alien_hurt(object *alien, object *attacker, int damage, bool ion)
 		if (!(alien->flags & FL_DISABLED))
 		{
 			alien->flags += FL_DISABLED;
-			updateMissionRequirements(M_DISABLE_TARGET,
+			mission_updateRequirements(M_DISABLE_TARGET,
 				alien->classDef, 1);
 		}
 
