@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,24 +20,27 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef ALIEN_H
 #define ALIEN_H
 
-extern object alien_defs[CD_MAX];
-extern object aliens[ALIEN_MAX];
+#include "defs.h"
+#include "structs.h"
+
+extern Object alien_defs[CD_MAX];
+extern Object aliens[ALIEN_MAX];
 
 void alien_defs_init();
 void aliens_init();
-bool alien_add();
-void alien_addDrone(object *hostAlien);
-void alien_addSmallAsteroid(object *hostAlien);
+int alien_add();
+void alien_addDrone(Object *hostAlien);
+void alien_addSmallAsteroid(Object *hostAlien);
 void alien_addFriendly(int type);
-bool alien_place(object *alien);
-void alien_setAI(object *alien);
-void alien_setKlineAttackMethod(object *alien);
-void alien_setKlineAI(object *alien);
-void alien_searchForTarget(object *alien);
-int alien_checkTarget(object *alien);
-int alien_enemiesInFront(object *alien);
-void alien_move(object *alien);
-void alien_destroy(object *alien, object *attacker);
-void alien_hurt(object *alien, object *attacker, int damage, bool ion);
+int alien_place(Object *alien);
+void alien_setAI(Object *alien);
+void alien_setKlineAttackMethod(Object *alien);
+void alien_setKlineAI(Object *alien);
+void alien_searchForTarget(Object *alien);
+int alien_checkTarget(Object *alien);
+int alien_enemiesInFront(Object *alien);
+void alien_move(Object *alien);
+void alien_destroy(Object *alien, Object *attacker);
+void alien_hurt(Object *alien, Object *attacker, int damage, int ion);
 
 #endif
