@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,21 +17,30 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdlib.h>
 
-void bullet_add(object *theWeapon, object *attacker, int y, int dy)
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "player.h"
+
+void bullet_add(Object *theWeapon, Object *attacker, int y, int dy)
 {
-	object *bullet;
+	Object *bullet;
 	int imageIndex;
 	int tempX, tempY, steps;
 
-	bullet = new object;
+	bullet = new Object;
 
 	if (attacker == &player)
 		game.shots++;
 
 	bullet->next = NULL;
-	bullet->active = true;
+	bullet->active = 1;
 	bullet->x = attacker->x + (attacker->image[0]->w / 2) -
 		(theWeapon->image[0]->w * attacker->face);
 	bullet->y = attacker->y + y;
@@ -40,7 +49,7 @@ void bullet_add(object *theWeapon, object *attacker, int y, int dy)
 
 	// Timed explosions live between 1 and 3 seconds
 	if (bullet->flags & WF_TIMEDEXPLOSION)
-		bullet->shield = 60 + ((rand() % 3) * 60);
+		bullet->shield = RANDRANGE(60, 180);
 
 	if (attacker->face == 0)
 	{
@@ -118,7 +127,7 @@ void bullet_add(object *theWeapon, object *attacker, int y, int dy)
 		if (!(bullet->flags & WF_TIMEDEXPLOSION))
 			steps /= 8;
 		else
-			steps /= 6 + (rand() % 6);
+			steps /= RANDRANGE(6, 11);
 
 		tempX = (int)(attacker->target->x - attacker->x);
 		tempY = (int)(attacker->target->y - attacker->y);
@@ -145,17 +154,15 @@ already have a target. If the target it is currently chasing is killed, it will
 begin to look for a new one (done in doBullets()). The homing missile will make
 one attempt per call (one call per frame) to find a suitable target. If the target
 it picks is dead or outside the screen range, then it returns NULL. A suitable
-target will be returned as the object address.
+target will be returned as the Object address.
 */
-object *bullet_getTarget(object *bullet)
+Object *bullet_getTarget(Object *bullet)
 {
 	int i;
 
 	if (bullet->owner->flags & FL_WEAPCO)
 	{
-		i = (rand() % 10);
-
-		if (i < 1)
+		if (CHANCE(0.1))
 			return &player;
 	}
 
@@ -182,7 +189,7 @@ object *bullet_getTarget(object *bullet)
 	return &aliens[i];
 }
 
-bool bullet_collision(object *bullet, object *ship)
+int bullet_collision(Object *bullet, Object *ship)
 {
 	float x0 = bullet->x;
 	float y0 = bullet->y;
