@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,8 +20,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef BULLETS_H
 #define BULLETS_H
 
-void bullet_add(object *theWeapon, object *attacker, int y, int dy);
-object *bullet_getTarget(object *bullet);
-bool bullet_collision(object *bullet, object *ship);
+#include "defs.h"
+#include "structs.h"
+
+void bullet_add(Object *theWeapon, Object *attacker, int y, int dy);
+Object *bullet_getTarget(Object *bullet);
+int bullet_collision(Object *bullet, Object *ship);
 
 #endif
