@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,10 +20,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef _CARGO_H_
 #define _CARGO_H_
 
-extern object cargo[MAX_CARGO];
+#include "defs.h"
+#include "structs.h"
+
+extern Object cargo[MAX_CARGO];
 
 void cargo_init();
-object *cargo_add(object *owner, int cargoType);
+Object *cargo_add(Object *owner, int cargoType);
 void cargo_becomeCollectable(int i);
 
 #endif
