@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,19 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdlib.h>
+
+#include "defs.h"
+#include "structs.h"
+
+#include "audio.h"
+#include "collectable.h"
+#include "engine.h"
+#include "explosion.h"
+#include "game.h"
+#include "gfx.h"
+#include "player.h"
+#include "weapons.h"
 
 /*
 Create a new collectable item based on supplied arguments.
@@ -84,9 +96,9 @@ void collectable_add(float x, float y, int type, int value, int life)
 	// upgraded! Give them money instead.
 	if (type == P_PLASMA_AMMO)
 	{
-		if ((weapon[W_PLAYER_WEAPON].reload[0] >= rate2reload[game.minPlasmaRate]) &&
-			(weapon[W_PLAYER_WEAPON].ammo[0] <= game.minPlasmaOutput) &&
-			(weapon[W_PLAYER_WEAPON].damage <= game.minPlasmaDamage))
+		if ((weapons[W_PLAYER_WEAPON].reload[0] >= rate2reload[game.minPlasmaRate]) &&
+			(weapons[W_PLAYER_WEAPON].ammo[0] <= game.minPlasmaOutput) &&
+			(weapons[W_PLAYER_WEAPON].damage <= game.minPlasmaDamage))
 		{
 			type = P_CASH;
 		}
@@ -131,10 +143,10 @@ void collectable_add(float x, float y, int type, int value, int life)
 		}
 	}
 
-	collectables *collectable = new collectables;
+	Collectable *collectable = new Collectable;
 
 	collectable->next = NULL;
-	collectable->active = true;
+	collectable->active = 1;
 	collectable->x = x;
 	collectable->y = y;
 
@@ -206,7 +218,7 @@ void collectable_add(float x, float y, int type, int value, int life)
 	engine.collectableTail = collectable;
 }
 
-bool collectable_collision(collectables *collectable, object *ship)
+int collectable_collision(Collectable *collectable, Object *ship)
 {
 	float x0 = collectable->x;
 	float y0 = collectable->y;
@@ -227,7 +239,7 @@ bool collectable_collision(collectables *collectable, object *ship)
 	return !(x1<x2 || x3<x0 || y1<y2 || y3<y0);
 }
 
-void collectable_explode(collectables *collectable)
+void collectable_explode(Collectable *collectable)
 {
 	audio_playSound(SFX_EXPLOSION, collectable->x, collectable->y);
 
