@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2012, 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2012, 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,8 +20,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef DEFS_H
 #define DEFS_H
 
-#include <stdlib.h>
-
 
 // Macros
 #define MIN(a, b) ((a) < (b) ? (a) : (b))
@@ -35,6 +33,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 	((x) + (y) > (b) ? ((a) - (b)) : 0))
 #define CHANCE(x) ((rand() % RAND_MAX) < ((x) * RAND_MAX))
 #define RANDRANGE(x, y) (((x) < (y)) ? ((x) + (rand() % (long)(1 + (y) - (x)))) : (x))
+#define DRAND ((double)rand() / RAND_MAX)
 
 
 // Compile-time options
@@ -58,6 +57,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define PATH_MAX 4096
 #endif
 
+#define FULLSCREEN SDL_WINDOW_FULLSCREEN
+
 #define STARS_NUM 200
 
 // Object Flags
@@ -84,6 +85,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define FL_ACTIVATE 1048576L
 #define FL_HASMINIMUMSPEED 2097152L
 #define FL_FIRELASER 4194304L
+#define FL_NOBANTER 8388608L
 
 // Weapon flags
 #define WF_SPREAD 4
@@ -97,9 +99,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define WF_DISABLE 1024
 #define WF_TIMEDEXPLOSION 2048
 
+#define MT_NONE -2
+
 #define MAX_CARGO 20
 #define MAX_INFOLINES 3
 #define MAX_EVENTS 20
+#define MAX_PLANETS 10
 
 
 enum keys {
@@ -496,6 +501,7 @@ enum {
 	TS_LOAD_GAME,
 	TS_CONTINUE_CURRENT_GAME,
 	TS_OPTIONS,
+	TS_CREDITS,
 	TS_CHEAT_OPTIONS,
 	TS_QUIT,
 	TS_SOUND,
