@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,19 +17,41 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
-
-#include <sys/types.h>
-#include <pwd.h>
-#include <unistd.h>
 #include <errno.h>
+#include <stdio.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
+#ifndef _WIN32
+#include <pwd.h>
+#endif
+
+#include "SDL.h"
+
+#ifndef NOSOUND
+#include "SDL_mixer.h"
+#endif
+
+#include "colors.h"
+#include "defs.h"
+#include "structs.h"
+
+#include "audio.h"
+#include "collectable.h"
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "player.h"
+#include "renderer.h"
+#include "screen.h"
+#include "window.h"
 
 Engine engine;
 
 void engine_init()
 {
 	engine.musicVolume = 100;
-	engine.useAudio = true;
+	engine.useAudio = 1;
 
 	engine.maxAliens = 9;
 
@@ -38,19 +60,19 @@ void engine_init()
 	engine.smx = 0;
 	engine.smy = 0;
 
-	engine.bulletHead = new object;
+	engine.bulletHead = new Object;
 	engine.bulletHead->next = NULL;
 	engine.bulletTail = engine.bulletHead;
 
-	engine.explosionHead = new object;
+	engine.explosionHead = new Object;
 	engine.explosionHead->next = NULL;
 	engine.explosionTail = engine.explosionHead;
 
-	engine.collectableHead = new collectables;
+	engine.collectableHead = new Collectable;
 	engine.collectableHead->next = NULL;
 	engine.collectableTail = engine.collectableHead;
 
-	engine.debrisHead = new object;
+	engine.debrisHead = new Object;
 	engine.debrisHead->next = NULL;
 	engine.debrisTail = engine.debrisHead;
 
@@ -66,13 +88,13 @@ void engine_init()
 	engine.counter = 0;
 	engine.seconds = 0;
 	engine.minutes = 0;
-	engine.paused = false;
+	engine.paused = 0;
 	engine.gameSection = SECTION_TITLE;
 
-	engine.cheat = false;
-	engine.cheatShield = false;
-	engine.cheatAmmo = false;
-	engine.cheatCash = false;
+	engine.cheat = 0;
+	engine.cheatShield = 0;
+	engine.cheatAmmo = 0;
+	engine.cheatCash = 0;
 }
 
 /*
@@ -125,7 +147,7 @@ void engine_showError(int errorId, const char *name)
 
 	while (!engine.keyState[KEY_ALTFIRE])
 	{
-		getPlayerInput();
+		player_getInput();
 		game_delayFrame();
 	}
 
@@ -138,20 +160,37 @@ This gets the user's home directory, then creates the config directory.
 void engine_setupConfigDirectory()
 {
 	const char *userHome;
+	char dir[PATH_MAX];
 
+#ifdef _WIN32
+	// XXX: This is a bad design, but I just can't be bothered to learn
+	// the Windows API so I can do this properly. If anyone wants to
+	// make this point to the proper directory, be my guest!
+	userHome = ".";
+#else
 	if ((userHome = getenv("HOME")) == NULL)
 		userHome = getpwuid(getuid())->pw_dir;
+#endif
 
-	char dir[PATH_MAX];
 	strcpy(dir, "");
 
 	sprintf(dir, "%s/.config", userHome);
+
+#ifdef _WIN32
+	if ((mkdir(dir) != 0) && (errno != EEXIST))
+		engine_showError(2, dir);
+
+	sprintf(dir, "%s/.config/starfighter", userHome);
+	if ((mkdir(dir) != 0) && (errno != EEXIST))
+		engine_showError(2, dir);
+#else
 	if ((mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0) && (errno != EEXIST))
 		engine_showError(2, dir);
 
 	sprintf(dir, "%s/.config/starfighter", userHome);
 	if ((mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0) && (errno != EEXIST))
 		engine_showError(2, dir);
+#endif
 
 	sprintf(engine.configDirectory, "%s/.config/starfighter/", userHome);
 }
@@ -211,7 +250,7 @@ void engine_setMode()
 	}
 
 	SDL_SetWindowIcon(window, gfx_loadImage("gfx/alienDevice.png"));
-	SDL_SetWindowFullscreen(window, engine.fullScreen ? SDL_WINDOW_FULLSCREEN_DESKTOP : 0);
+	SDL_SetWindowFullscreen(window, engine.fullScreen ? FULLSCREEN : 0);
 
 	renderer = SDL_CreateRenderer(window, -1, 0);
 
@@ -231,15 +270,17 @@ void engine_setMode()
 		exit(1);
 	}
 
+#ifndef NOSOUND
 	if (engine.useAudio)
 	{
 		if (Mix_OpenAudio(44100, AUDIO_S16, engine.useAudio * 2, 1024) < 0)
 		{
 			printf("Warning: Couldn't set 44100 Hz 16-bit stereo audio - Reason:\n%s\n", Mix_GetError());
 			printf("Sound and Music will be disabled\n");
-			engine.useAudio = false;
+			engine.useAudio = 0;
 		}
 	}
+#endif
 
 	SDL_ShowCursor(SDL_DISABLE);
 	SDL_EventState(SDL_MOUSEMOTION, SDL_DISABLE);
@@ -248,6 +289,65 @@ void engine_setMode()
 	SDL_JoystickOpen(0);
 }
 
+void engine_resetLists()
+{
+	Object *ob, *ob2;
+	Collectable *c1, *c2;
+	LinkedRect *r1, *r2;
+
+	ob = engine.bulletHead->next;
+	while(ob != NULL)
+	{
+		ob2 = ob;
+		ob = ob->next;
+		delete ob2;
+	}
+	engine.bulletHead->next = NULL;
+	engine.bulletTail = engine.bulletHead;
+
+	ob = engine.explosionHead->next;
+	while(ob != NULL)
+	{
+		ob2 = ob;
+		ob = ob->next;
+		delete ob2;
+	}
+	engine.explosionHead->next = NULL;
+	engine.explosionTail = engine.explosionHead;
+
+	c1 = engine.collectableHead->next;
+	while (c1 != NULL)
+	{
+		c2 = c1;
+		c1 = c1->next;
+		delete c2;
+	}
+
+	engine.collectableHead->next = NULL;
+	engine.collectableTail = engine.collectableHead;
+	
+	r1 = screen_bufferHead->next;
+	while (r1 != NULL)
+	{
+		r2 = r1;
+		r1 = r1->next;
+		delete r2;
+	}
+	
+	screen_bufferHead->next = NULL;
+	screen_bufferTail = screen_bufferHead;
+
+	ob = engine.debrisHead->next;
+	while(ob != NULL)
+	{
+		ob2 = ob;
+		ob = ob->next;
+		delete ob2;
+	}
+	engine.debrisHead->next = NULL;
+	engine.debrisTail = engine.debrisHead;
+}
+
 /*
 Removes [hopefully] all the resources that has been
 loaded and created during the game. This is called by
@@ -258,7 +358,7 @@ void engine_cleanup()
 	gfx_free();
 	SDL_FreeSurface(gfx_background);
 	audio_free();
-	resetLists();
+	engine_resetLists();
 	delete(engine.bulletHead);
 	delete(engine.explosionHead);
 	delete(engine.collectableHead);
@@ -272,17 +372,13 @@ void engine_cleanup()
 
 	char filename[PATH_MAX];
 	strcpy(filename, "");
-	
-	sprintf(filename, "%smusic.mod", engine.configDirectory);
-	remove(filename);
-
-	sprintf(filename, "%smusic.s3m", engine.configDirectory);
-	remove(filename);
 
+#ifndef NOSOUND
 	if (engine.useAudio)
 	{
 		Mix_CloseAudio();
 	}
+#endif
 
 	// Save the config using current settings
 	FILE *fp;
