@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,10 +17,13 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef EXPLOSIONS_H
-#define EXPLOSIONS_H
+#ifndef EXPLOSION_H
+#define EXPLOSION_H
+
+#include "defs.h"
+#include "structs.h"
 
 void explosion_add(float x, float y, int type);
-void explosion_addEngine(object *craft);
+void explosion_addEngine(Object *craft);
 
 #endif
