@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2014, 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2012, 2014-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,45 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <math.h>
+#include <stdio.h>
+#include <stdlib.h>
+
+#include "SDL.h"
+
+#include "colors.h"
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "bullet.h"
+#include "cargo.h"
+#include "collectable.h"
+#include "cutscene.h"
+#include "engine.h"
+#include "event.h"
+#include "explosion.h"
+#include "game.h"
+#include "gfx.h"
+#include "info.h"
+#include "intermission.h"
+#include "mission.h"
+#include "player.h"
+#include "radio.h"
+#include "renderer.h"
+#include "save.h"
+#include "screen.h"
+#include "ship.h"
+#include "title.h"
+#include "weapons.h"
+
+typedef struct Star_ {
+
+	float x, y, dx, dy;
+	int speed; // How fast the star moves
+
+} Star;
 
 Game game;
 
@@ -25,6 +63,47 @@ static Star stars[STARS_NUM];
 static Uint32 frameLimit = 0;
 static int thirds = 0;
 
+static const int nKlineInsult = 3;
+static const char *klineInsult[nKlineInsult] = {
+	"Pathetic.", "How very disappointing...", "Heroic. And stupid."
+};
+
+static const int nKlineVenusInsult = 2;
+static const char *klineVenusInsult[nKlineVenusInsult] = {
+	"Fool.", "And now you're nothing but a DEAD hero."
+};
+
+static const int nPhoebePlayerHitMessage = 3;
+static const char *phoebePlayerHitMessage[nPhoebePlayerHitMessage] = {
+	"Oops! Sorry!",
+	"Whoops! Are you OK, Chris?",
+	"Oh, sorry! I didn't see you there!"
+};
+
+static const int nUrsulaPlayerHitMessage = 3;
+static const char *ursulaPlayerHitMessage[nUrsulaPlayerHitMessage] = {
+	"Get out of the way!",
+	"Don't fly into my missiles!",
+	"Dammit, Chris, you made me miss!"
+};
+
+static const int nPlayerPhoebeHitMessage = 3;
+static const char *playerPhoebeHitMessage[nPlayerPhoebeHitMessage] = {
+	"OW! I hope that was an accident!",
+	"Chris, please be more careful!",
+	"Ouch! What are you shooting at me for?"
+};
+
+static const int nPlayerUrsulaHitMessage = 5;
+static const char *playerUrsulaHitMessage[nPlayerUrsulaHitMessage] = {
+	"I am NOT your enemy!",
+	"Hey! Watch it!",
+	"What are you doing?! Shoot THEM!",
+	"Open your eyes!",
+	"Are you blind?!"
+};
+
+
 void game_init()
 {
 	game.system = SYSTEM_SPIRIT;
@@ -34,8 +113,8 @@ void game_init()
 
 	if (!engine.useAudio)
 	{
-		engine.useSound = false;
-		engine.useMusic = false;
+		engine.useSound = 0;
+		engine.useMusic = 0;
 	}
 
 	game.cash = 0;
@@ -135,9 +214,9 @@ void game_init()
 		stars[i].speed = 1 + (rand() % 3);
 	}
 
-	initWeapons();
-	initMissions();
-	initPlanetMissions(game.system);
+	weapons_init();
+	mission_init();
+	intermission_initPlanets(game.system);
 }
 
 static void game_addDebris(int x, int y, int amount)
@@ -147,14 +226,14 @@ static void game_addDebris(int x, int y, int amount)
 	else
 		audio_playSound(SFX_DEBRIS2, x, y);
 
-	object *debris;
+	Object *debris;
 	
 	amount = RANDRANGE(3, amount);
 	LIMIT(amount, 3, 8);
 
 	for (int i = 0 ; i < amount ; i++)
 	{
-		debris = new object;
+		debris = new Object;
 
 		debris->next = NULL;
 		debris->x = x;
@@ -231,8 +310,8 @@ will be updated. Information will be displayed and appropriate player variables
 */
 static void game_doCollectables()
 {
-	collectables *collectable = engine.collectableHead;
-	collectables *prevCollectable = engine.collectableHead;
+	Collectable *collectable = engine.collectableHead;
+	Collectable *prevCollectable = engine.collectableHead;
 	engine.collectableTail = engine.collectableHead;
 	char temp[40];
 
@@ -294,9 +373,17 @@ static void game_doCollectables()
 						if (game.difficulty == DIFFICULTY_ORIGINAL)
 						{
 							player.ammo[0] = MAX(player.ammo[0], 50);
-							weapon[W_PLAYER_WEAPON].reload[0] = MAX(
+							weapons[W_PLAYER_WEAPON].reload[0] = MAX(
 								rate2reload[game.maxPlasmaRate],
-								weapon[W_PLAYER_WEAPON].reload[0] - 2);
+								weapons[W_PLAYER_WEAPON].reload[0] - 2);
+
+							if (weapons[W_PLAYER_WEAPON].reload[0] <= rate2reload[game.maxPlasmaRate])
+								sprintf(temp, "Firing rate already at maximum");
+							else
+							{
+								weapons[W_PLAYER_WEAPON].reload[0] -= 2;
+								sprintf(temp, "Firing rate increased");
+							}
 						}
 						else if ((game.area != MISN_INTERCEPTION) ||
 								(player.ammo[0] > 0))
@@ -305,11 +392,11 @@ static void game_doCollectables()
 								LIMIT_ADD(player.ammo[0], collectable->value,
 									0, game.maxPlasmaAmmo);
 
-							if (weapon[W_PLAYER_WEAPON].reload[0] <= rate2reload[game.maxPlasmaRate])
+							if (weapons[W_PLAYER_WEAPON].reload[0] <= rate2reload[game.maxPlasmaRate])
 								sprintf(temp, "Firing rate already at maximum");
 							else
 							{
-								weapon[W_PLAYER_WEAPON].reload[0] -= 2;
+								weapons[W_PLAYER_WEAPON].reload[0] -= 2;
 								sprintf(temp, "Firing rate increased");
 							}
 						}
@@ -324,8 +411,16 @@ static void game_doCollectables()
 						if (game.difficulty == DIFFICULTY_ORIGINAL)
 						{
 							player.ammo[0] = MAX(player.ammo[0], 50);
-							weapon[W_PLAYER_WEAPON].ammo[0] = MIN(
-								game.maxPlasmaOutput, weapon[W_PLAYER_WEAPON].ammo[0] + 1);
+							weapons[W_PLAYER_WEAPON].ammo[0] = MIN(
+								game.maxPlasmaOutput, weapons[W_PLAYER_WEAPON].ammo[0] + 1);
+
+							if (weapons[W_PLAYER_WEAPON].ammo[0] >= game.maxPlasmaOutput)
+								sprintf(temp, "Plasma output already at maximum");
+							else
+							{
+								weapons[W_PLAYER_WEAPON].ammo[0]++;
+								sprintf(temp, "Plasma output increased");
+							}
 						}
 						else if ((game.area != MISN_INTERCEPTION) ||
 								(player.ammo[0] > 0))
@@ -334,11 +429,11 @@ static void game_doCollectables()
 								LIMIT_ADD(player.ammo[0], collectable->value,
 									0, game.maxPlasmaAmmo);
 
-							if (weapon[W_PLAYER_WEAPON].ammo[0] >= game.maxPlasmaOutput)
+							if (weapons[W_PLAYER_WEAPON].ammo[0] >= game.maxPlasmaOutput)
 								sprintf(temp, "Plasma output already at maximum");
 							else
 							{
-								weapon[W_PLAYER_WEAPON].ammo[0]++;
+								weapons[W_PLAYER_WEAPON].ammo[0]++;
 								sprintf(temp, "Plasma output increased");
 							}
 						}
@@ -353,8 +448,16 @@ static void game_doCollectables()
 						if (game.difficulty == DIFFICULTY_ORIGINAL)
 						{
 							player.ammo[0] = MAX(player.ammo[0], 50);
-							weapon[W_PLAYER_WEAPON].damage = MIN(
-								game.maxPlasmaDamage, weapon[W_PLAYER_WEAPON].damage + 1);
+							weapons[W_PLAYER_WEAPON].damage = MIN(
+								game.maxPlasmaDamage, weapons[W_PLAYER_WEAPON].damage + 1);
+
+							if (weapons[W_PLAYER_WEAPON].damage >= game.maxPlasmaDamage)
+								sprintf(temp, "Plasma damage already at maximum");
+							else
+							{
+								weapons[W_PLAYER_WEAPON].damage++;
+								sprintf(temp, "Plasma damage increased");
+							}
 						}
 						else if ((game.area != MISN_INTERCEPTION) ||
 								(player.ammo[0] > 0))
@@ -363,11 +466,11 @@ static void game_doCollectables()
 								LIMIT_ADD(player.ammo[0], collectable->value,
 									0, game.maxPlasmaAmmo);
 
-							if (weapon[W_PLAYER_WEAPON].damage >= game.maxPlasmaDamage)
+							if (weapons[W_PLAYER_WEAPON].damage >= game.maxPlasmaDamage)
 								sprintf(temp, "Plasma damage already at maximum");
 							else
 							{
-								weapon[W_PLAYER_WEAPON].damage++;
+								weapons[W_PLAYER_WEAPON].damage++;
 								sprintf(temp, "Plasma damage increased");
 							}
 						}
@@ -389,12 +492,12 @@ static void game_doCollectables()
 								LIMIT_ADD(player.ammo[0], collectable->value,
 									0, game.maxPlasmaAmmo);
 
-							weapon[W_PLAYER_WEAPON].ammo[0] = 5;
-							weapon[W_PLAYER_WEAPON].damage = 5;
-							weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[5];
-							weapon[W_PLAYER_WEAPON].flags |= WF_SPREAD;
+							weapons[W_PLAYER_WEAPON].ammo[0] = 5;
+							weapons[W_PLAYER_WEAPON].damage = 5;
+							weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[5];
+							weapons[W_PLAYER_WEAPON].flags |= WF_SPREAD;
 
-							sprintf(temp, "Picked up a Super Charge!!");
+							sprintf(temp, "Picked up a Super Charge!");
 						}
 						else
 						{
@@ -442,13 +545,13 @@ static void game_doCollectables()
 						break;
 				}
 
-				updateMissionRequirements(M_COLLECT, collectable->type,
+				mission_updateRequirements(M_COLLECT, collectable->type,
 					collectable->value);
 
-				collectable->active = false;
+				collectable->active = 0;
 				if (collectable->type != P_MINE)
 				{
-					setInfoLine(temp, FONT_WHITE);
+					info_setLine(temp, FONT_WHITE);
 					if (collectable->type == P_SHIELD)
 						audio_playSound(SFX_SHIELDUP, player.x, player.y);
 					else
@@ -459,19 +562,19 @@ static void game_doCollectables()
 			// stop people from exploiting a weapon check condition
 			if (player.ammo[0] == 0)
 			{
-				weapon[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
-				weapon[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
-				weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
+				weapons[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
+				weapons[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
+				weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
 			}
 		}
 
 		if (collectable->life < 1)
 		{
-			collectable->active = false;
+			collectable->active = 0;
 			if ((collectable->type == P_CARGO) ||
 					(collectable->type == P_ESCAPEPOD) ||
 					(collectable->type == P_SLAVES))
-				updateMissionRequirements(M_PROTECT_PICKUP, collectable->type, 1);
+				mission_updateRequirements(M_PROTECT_PICKUP, collectable->type, 1);
 		}
 
 		if (collectable->active)
@@ -504,13 +607,13 @@ spawned.
 */
 static void game_doBullets()
 {
-	object *bullet = engine.bulletHead;
-	object *prevBullet = engine.bulletHead;
+	Object *bullet = engine.bulletHead;
+	Object *prevBullet = engine.bulletHead;
 
-	collectables *collectable;
-	collectables *prevCollectable;
+	Collectable *collectable;
+	Collectable *prevCollectable;
 
-	bool okayToHit = false;
+	int okayToHit = 0;
 	int old_shield;
 	float homingMissileSpeed = 0;
 	int charger_num;
@@ -576,7 +679,7 @@ static void game_doBullets()
 				else if (bullet->x > bullet->target->x)
 					LIMIT_ADD(bullet->dx, -homingMissileSpeed, -15, 15);
 
-				//Rocket is (more or less) inline with target. Fly straight
+				//Rocket is (more or less) in line with target. Fly straight
 				if ((bullet->x > bullet->target->x - 1) && (bullet->x < bullet->target->x + 5))
 					bullet->dx = 0;
 
@@ -585,7 +688,7 @@ static void game_doBullets()
 				else if (bullet->y > bullet->target->y)
 					LIMIT_ADD(bullet->dy, -homingMissileSpeed, -15, 15);
 
-				//Rocket is (more or less) inline with target. Fly straight
+				//Rocket is (more or less) in line with target. Fly straight
 				if ((bullet->y > bullet->target->y - 1) && (bullet->y < bullet->target->y + 5))
 					bullet->dy = 0;
 
@@ -601,18 +704,18 @@ static void game_doBullets()
 				if ((aliens[i].shield < 1) || (!aliens[i].active))
 					continue;
 
-				okayToHit = false;
+				okayToHit = 0;
 
 				if ((bullet->flags & WF_FRIEND) && (aliens[i].flags & FL_WEAPCO))
-					okayToHit = true;
+					okayToHit = 1;
 				if ((bullet->flags & WF_WEAPCO) && (aliens[i].flags & FL_FRIEND))
-					okayToHit = true;
+					okayToHit = 1;
 				if ((bullet->id == WT_ROCKET) || (bullet->id == WT_LASER) ||
 						(bullet->id == WT_CHARGER))
-					okayToHit = true;
+					okayToHit = 1;
 
 				if (bullet->owner == aliens[i].owner)
-					okayToHit = false;
+					okayToHit = 0;
 
 				if (okayToHit)
 				{
@@ -623,9 +726,10 @@ static void game_doBullets()
 						if (bullet->owner == &player)
 						{
 							game.hits++;
-							if ((aliens[i].classDef == CD_PHOEBE) ||
-									(aliens[i].classDef == CD_URSULA))
-								getMissFireMessage(&aliens[i]);
+							if (aliens[i].classDef == CD_PHOEBE)
+								radio_setMessage(FS_PHOEBE, playerPhoebeHitMessage[rand() % nPlayerPhoebeHitMessage], 0);
+							else if (aliens[i].classDef == CD_URSULA)
+								radio_setMessage(FS_URSULA, playerUrsulaHitMessage[rand() % nPlayerUrsulaHitMessage], 0);
 						}
 
 						if (!(aliens[i].flags & FL_IMMORTAL))
@@ -648,7 +752,7 @@ static void game_doBullets()
 							bullet->damage -= old_shield;
 							if (bullet->damage <= 0)
 							{
-								bullet->active = false;
+								bullet->active = 0;
 								bullet->shield = 0;
 								audio_playSound(SFX_EXPLOSION, bullet->x, bullet->y);
 								for (int i = 0 ; i < 10 ; i++)
@@ -659,7 +763,7 @@ static void game_doBullets()
 						}
 						else
 						{
-							bullet->active = false;
+							bullet->active = 0;
 							bullet->shield = 0;
 						}
 
@@ -684,23 +788,31 @@ static void game_doBullets()
 					{
 						if ((player.shield > engine.lowShield) &&
 								(player.shield - bullet->damage <= engine.lowShield))
-							setInfoLine("!!! WARNING: SHIELD LOW !!!", FONT_RED);
+							info_setLine("!!! WARNING: SHIELD LOW !!!", FONT_RED);
 
 						player.shield -= bullet->damage;
 						LIMIT(player.shield, 0, player.maxShield);
 						player.hit = 5;
 					}
 
-					if ((bullet->owner->classDef == CD_PHOEBE) ||
-							(bullet->owner->classDef == CD_URSULA))
-						getPlayerHitMessage(bullet->owner);
+					if (player.shield > 0)
+					{
+						if (bullet->owner->classDef == CD_PHOEBE)
+						{
+							radio_setMessage(FS_PHOEBE, phoebePlayerHitMessage[rand() % nPhoebePlayerHitMessage], 0);
+						}
+						else if (bullet->owner->classDef == CD_URSULA)
+						{
+							radio_setMessage(FS_URSULA, ursulaPlayerHitMessage[rand() % nUrsulaPlayerHitMessage], 0);
+						}
+					}
 
 					if (bullet->id == WT_CHARGER)
 					{
 						bullet->damage -= old_shield;
 						if (bullet->damage <= 0)
 						{
-							bullet->active = false;
+							bullet->active = 0;
 							bullet->shield = 0;
 							audio_playSound(SFX_EXPLOSION, bullet->x, bullet->y);
 							for (int i = 0 ; i < 10 ; i++)
@@ -710,7 +822,7 @@ static void game_doBullets()
 					}
 					else
 					{
-						bullet->active = false;
+						bullet->active = 0;
 						bullet->shield = 0;
 					}
 
@@ -733,18 +845,18 @@ static void game_doBullets()
 				{
 					if (bullet_collision(bullet, &cargo[j]))
 					{
-						bullet->active = false;
+						bullet->active = 0;
 						explosion_add(bullet->x, bullet->y, SP_SMALL_EXPLOSION);
 						audio_playSound(SFX_HIT, cargo[j].x, cargo[j].y);
 						if (cargo[j].collectType != P_PHOEBE)
 						{
-							cargo[j].active = false;
+							cargo[j].active = 0;
 							audio_playSound(SFX_EXPLOSION, cargo[j].x, cargo[j].y);
 							for (int i = 0 ; i < 10 ; i++)
 								explosion_add(cargo[j].x + RANDRANGE(-15, 15),
 									cargo[j].y + RANDRANGE(-15, 15),
 									SP_BIG_EXPLOSION);
-							updateMissionRequirements(M_PROTECT_PICKUP,
+							mission_updateRequirements(M_PROTECT_PICKUP,
 								P_CARGO, 1);
 						}
 					}
@@ -764,17 +876,17 @@ static void game_doBullets()
 			{
 				if (collectable_collision(collectable, bullet))
 				{
-					collectable->active = false;
+					collectable->active = 0;
 					
 					if (bullet->id != WT_CHARGER)
 					{
-						bullet->active = false;
+						bullet->active = 0;
 					}
 					else
 					{
 						bullet->shield--;
 						if (bullet->shield < 0)
-							bullet->active = false;
+							bullet->active = 0;
 					}
 
 					if (bullet->owner == &player)
@@ -812,7 +924,7 @@ static void game_doBullets()
 
 				player_checkShockDamage(bullet->x, bullet->y);
 			}
-			bullet->active = false;
+			bullet->active = 0;
 		}
 
 		if (bullet->active)
@@ -834,7 +946,7 @@ static void game_doAliens()
 	static float barrierLoop = 0;
 
 	int shapeToUse;
-	bool canFire;
+	int canFire;
 	int n;
 
 	barrierLoop += 0.2;
@@ -879,7 +991,7 @@ static void game_doAliens()
 					}
 				}
 
-				canFire = true; // The alien is allowed to fire
+				canFire = 1; // The alien is allowed to fire
 
 				LIMIT_ADD(aliens[i].thinktime, -1, 0, 250);
 
@@ -959,21 +1071,21 @@ static void game_doAliens()
 					{
 						aliens[i].flags -= FL_LEAVESECTOR;
 						aliens[i].flags += FL_ESCAPED;
-						aliens[i].active = false;
+						aliens[i].active = 0;
 
 						if (aliens[i].classDef == CD_CLOAKFIGHTER)
 						{
 							game.experimentalShield = aliens[i].shield;
-							setInfoLine("Experimental Fighter has fled",
+							info_setLine("Experimental Fighter has fled",
 								FONT_CYAN);
 						}
 
 						aliens[i].shield = 0;
-						updateMissionRequirements(M_ESCAPE_TARGET,
+						mission_updateRequirements(M_ESCAPE_TARGET,
 							aliens[i].classDef, 1);
 					
 						if (aliens[i].classDef != CD_CLOAKFIGHTER)
-							updateMissionRequirements(M_DESTROY_TARGET_TYPE,
+							mission_updateRequirements(M_DESTROY_TARGET_TYPE,
 								aliens[i].classDef, 1);
 					}
 				}
@@ -1019,7 +1131,7 @@ static void game_doAliens()
 				}
 				else
 				{
-					canFire = false;
+					canFire = 0;
 				}
 
 				if (canFire)
@@ -1114,7 +1226,7 @@ static void game_doAliens()
 				}
 
 				if ((game.area == MISN_MARS) && (aliens[i].x < -60))
-					aliens[i].active = false;
+					aliens[i].active = 0;
 			}
 			else
 			{
@@ -1130,7 +1242,7 @@ static void game_doAliens()
 				}
 				if (aliens[i].shield < aliens[i].deathCounter)
 				{
-					aliens[i].active = false;
+					aliens[i].active = 0;
 					if ((aliens[i].classDef == CD_BOSS) ||
 							(aliens[i].owner == &aliens[ALIEN_BOSS]) ||
 							(aliens[i].flags & FL_FRIEND) ||
@@ -1176,8 +1288,8 @@ static void game_doPlayer()
 	int shapeToUse;
 	float cd;
 	float cc;
-	bool xmoved = false;
-	bool ymoved = false;
+	int xmoved = 0;
+	int ymoved = 0;
 
 	if (player.shield > -100)
 	{
@@ -1201,12 +1313,12 @@ static void game_doPlayer()
 						ship_fireBullet(&player, 1);
 
 						if (!engine.cheatAmmo)
-							player.ammo[1] += 2;
+							player.ammo[1] += 1;
 
 						if (player.ammo[1] >= 100)
 						{
 							player.ammo[1] = 200;
-							setInfoLine("Laser Overheat!!", FONT_WHITE);
+							info_setLine("Laser Overheat!", FONT_WHITE);
 						}
 					}
 				}
@@ -1236,7 +1348,7 @@ static void game_doPlayer()
 							{
 								ship_fireBullet(&player, 1);
 								player.ammo[1] = 0;
-								player_chargerFired = true;
+								player_chargerFired = 1;
 							}
 						}
 					}
@@ -1246,24 +1358,24 @@ static void game_doPlayer()
 					if (player.ammo[1] > 0)
 						ship_fireBullet(&player, 1);
 					player.ammo[1] = 0;
-					player_chargerFired = false;
+					player_chargerFired = 0;
 				}
 			}
 
 			if ((engine.keyState[KEY_SWITCH]))
 			{
-				if ((weapon[W_PLAYER_WEAPON].ammo[0] >= 3) &&
-					(weapon[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput))
+				if ((weapons[W_PLAYER_WEAPON].ammo[0] >= 3) &&
+					(weapons[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput))
 				{
-					weapon[W_PLAYER_WEAPON].flags ^= WF_SPREAD;
+					weapons[W_PLAYER_WEAPON].flags ^= WF_SPREAD;
 
-					if (weapon[W_PLAYER_WEAPON].flags & WF_SPREAD)
+					if (weapons[W_PLAYER_WEAPON].flags & WF_SPREAD)
 					{
-						setInfoLine("Weapon set to Spread", FONT_WHITE);
+						info_setLine("Weapon set to Spread", FONT_WHITE);
 					}
 					else
 					{
-						setInfoLine("Weapon set to Concentrate", FONT_WHITE);
+						info_setLine("Weapon set to Concentrate", FONT_WHITE);
 					}
 				}
 
@@ -1277,14 +1389,14 @@ static void game_doPlayer()
 			{
 				player.y -= player.speed;
 				engine.ssy += 0.1;
-				ymoved = true;
+				ymoved = 1;
 			}
 
 			if (engine.keyState[KEY_DOWN])
 			{
 				player.y += player.speed;
 				engine.ssy -= 0.1;
-				ymoved = true;
+				ymoved = 1;
 			}
 
 			if (engine.keyState[KEY_LEFT])
@@ -1292,7 +1404,7 @@ static void game_doPlayer()
 				player.x -= player.speed;
 				engine.ssx += 0.1;
 				player.face = 1;
-				xmoved = true;
+				xmoved = 1;
 			}
 
 			if (engine.keyState[KEY_RIGHT])
@@ -1300,13 +1412,13 @@ static void game_doPlayer()
 				player.x += player.speed;
 				engine.ssx -= 0.1;
 				player.face = 0;
-				xmoved = true;
+				xmoved = 1;
 			}
 
 			if (engine.keyState[KEY_ESCAPE])
 			{
 				if ((engine.done == 0) && (engine.gameSection == SECTION_GAME) &&
-					(currentMission.remainingObjectives1 == 0))
+					(mission.remainingObjectives1 == 0))
 				{
 					audio_playSound(SFX_FLY, screen->w / 2, screen->h / 2);
 					engine.done = 2;
@@ -1316,7 +1428,7 @@ static void game_doPlayer()
 
 			if (engine.keyState[KEY_PAUSE])
 			{
-				engine.paused = true;
+				engine.paused = 1;
 				engine.keyState[KEY_PAUSE] = 0;
 			}
 
@@ -1324,8 +1436,8 @@ static void game_doPlayer()
 				(game.area == MISN_MARS))
 			{
 				player.face = 0;
-				xmoved = true;
-				ymoved = true;
+				xmoved = 1;
+				ymoved = 1;
 			}
 
 			if (engine.done == 0)
@@ -1419,12 +1531,21 @@ static void game_doPlayer()
 		}
 		else
 		{
-			player.active = false;
+			player.active = 0;
 			player.shield--;
 			if (player.shield == -1)
 			{
-				if ((game.hasWingMate1) || (aliens[ALIEN_KLINE].active))
-					getPlayerDeathMessage();
+				if (aliens[ALIEN_KLINE].active)
+				{
+					if (game.area == MISN_VENUS)
+						radio_setMessage(FS_KLINE, klineVenusInsult[rand() % nKlineVenusInsult], 1);
+					else
+						radio_setMessage(FS_KLINE, klineInsult[rand() % nKlineInsult], 1);
+				}
+				else if ((aliens[ALIEN_BOSS].active) && (aliens[ALIEN_BOSS].classDef == CD_KRASS))
+				{
+					radio_setMessage(FS_KRASS, "That was the easiest $90,000,000 I've ever earned! Bwah! Ha! Ha! Ha!", 1);
+				}
 
 				// Make it look like the ships are all still moving...
 				if (game.area == MISN_ELLESH)
@@ -1501,8 +1622,8 @@ static void game_doCargo()
 
 static void game_doDebris()
 {
-	object *prevDebris = engine.debrisHead;
-	object *debris = engine.debrisHead;
+	Object *prevDebris = engine.debrisHead;
+	Object *debris = engine.debrisHead;
 	engine.debrisTail = engine.debrisHead;
 
 	while (debris->next != NULL)
@@ -1544,8 +1665,8 @@ the explosion is killed off.
 */
 void game_doExplosions()
 {
-	object *prevExplosion = engine.explosionHead;
-	object *explosion = engine.explosionHead;
+	Object *prevExplosion = engine.explosionHead;
+	Object *explosion = engine.explosionHead;
 	engine.explosionTail = engine.explosionHead;
 	
 	while (explosion->next != NULL)
@@ -1565,7 +1686,7 @@ void game_doExplosions()
 
 				if(explosion->thinktime < 1)
 				{
-					explosion->active = false;
+					explosion->active = 0;
 				}
 				else
 				{
@@ -1687,7 +1808,7 @@ static void game_doHud()
 	if (game.area != MISN_INTERCEPTION)
 	{
 		screen_blitText(TS_OBJECTIVES_T);
-		sprintf(text, "%d", (currentMission.remainingObjectives1 + currentMission.remainingObjectives2));
+		sprintf(text, "%d", (mission.remainingObjectives1 + mission.remainingObjectives2));
 		gfx_createTextObject(TS_OBJECTIVES, text, screen->w - 55, 21, FONT_WHITE);
 		screen_blitText(TS_OBJECTIVES);
 	}
@@ -1719,7 +1840,7 @@ static void game_doHud()
 			fontColor = FONT_RED;
 		else
 			fontColor = FONT_WHITE;
-		sprintf(text, "%.3d", player.ammo[1]); // rocket ammo
+		sprintf(text, "%.2d", player.ammo[1]); // rocket ammo
 		gfx_createTextObject(TS_AMMO, text, screen->w / 2 + 80, screen->h - 49, fontColor);
 		screen_blitText(TS_AMMO);
 	}
@@ -1742,7 +1863,7 @@ static void game_doHud()
 		}
 	}
 
-	if ((!allMissionsCompleted()) && (SDL_GetTicks() >= engine.counter2))
+	if ((!mission_checkCompleted()) && (SDL_GetTicks() >= engine.counter2))
 	{
 		engine.timeTaken++;
 		engine.counter2 = SDL_GetTicks() + 1000;
@@ -1771,12 +1892,12 @@ static void game_doHud()
 				engine.counter = (SDL_GetTicks() + 1000);
 				for (int i = 0 ; i < 3 ; i++)
 				{
-					if (currentMission.timeLimit1[i] > -1)
-						currentMission.timeLimit1[i]--;
-					if (currentMission.timeLimit2[i] > -1)
-						currentMission.timeLimit2[i]--;
+					if (mission.timeLimit1[i] > -1)
+						mission.timeLimit1[i]--;
+					if (mission.timeLimit2[i] > -1)
+						mission.timeLimit2[i]--;
 				}
-				checkTimer();
+				mission_checkTimer();
 				events_check();
 			}
 
@@ -1784,12 +1905,12 @@ static void game_doHud()
 			{
 				for (int i = 0 ; i < 3 ; i++)
 				{
-					if (currentMission.timeLimit1[i] > -1)
-						currentMission.timeLimit1[i]--;
-					if (currentMission.timeLimit2[i] > -1)
-						currentMission.timeLimit2[i]--;
+					if (mission.timeLimit1[i] > -1)
+						mission.timeLimit1[i]--;
+					if (mission.timeLimit2[i] > -1)
+						mission.timeLimit2[i]--;
 				}
-				checkTimer();
+				mission_checkTimer();
 				events_check();
 				engine.counter = (SDL_GetTicks() + 1000);
 			}
@@ -1808,7 +1929,7 @@ static void game_doHud()
 			{
 				for (int j = i ; j < MAX_INFOLINES - 1 ; j++)
 				{
-					copyInfoLine(j + 1, j);
+					info_copyLine(j + 1, j);
 				}
 				gfx_textSprites[MAX_INFOLINES - 1].life = 0;
 			}
@@ -1866,7 +1987,7 @@ static void game_doHud()
 
 	for (int i = 1 ; i <= 5 ; i++)
 	{
-		if (weapon[W_PLAYER_WEAPON].damage >= i) {
+		if (weapons[W_PLAYER_WEAPON].damage >= i) {
 			if(i <= game.maxPlasmaDamage || (SDL_GetTicks() % 1000 > (unsigned)i * 100))
 			{
 				SDL_FillRect(screen, &bar, green);
@@ -1886,7 +2007,7 @@ static void game_doHud()
 
 	for (int i = 1 ; i <= 5 ; i++)
 	{
-		if (weapon[W_PLAYER_WEAPON].ammo[0] >= i) {
+		if (weapons[W_PLAYER_WEAPON].ammo[0] >= i) {
 			if(i <= game.maxPlasmaOutput || (SDL_GetTicks() % 1000 > (unsigned)i * 100))
 			{
 				SDL_FillRect(screen, &bar, yellow);
@@ -1906,7 +2027,7 @@ static void game_doHud()
 
 	for (int i = 1 ; i <= 5 ; i++)
 	{
-		if (weapon[W_PLAYER_WEAPON].reload[0] <= rate2reload[i]) {
+		if (weapons[W_PLAYER_WEAPON].reload[0] <= rate2reload[i]) {
 			if(i <= game.maxPlasmaRate || (SDL_GetTicks() % 1000 > (unsigned)i * 100))
 			{
 				SDL_FillRect(screen, &bar, blue);
@@ -1921,8 +2042,8 @@ static void game_doHud()
 	if (player.shield < 1)
 		return;
 
-	if ((!engine.keyState[KEY_ALTFIRE]) && (player.weaponType[1] == W_LASER) && (engine.eventTimer % 8 == 1))
-		LIMIT_ADD(player.ammo[1], -1, 1, 255);
+	if ((player.weaponType[1] == W_LASER) && (engine.eventTimer % 8 == 1))
+		LIMIT_ADD(player.ammo[1], -1, 0, 200);
 
 	if ((engine.eventTimer < 30) && (player.shield <= engine.lowShield))
 		return;
@@ -1976,28 +2097,27 @@ Checked during the main game loop. When the game is paused
 it goes into a constant loop checking this routine. If escape is
 pressed, the game automatically ends and goes back to the title screen
 */
-static bool game_checkPauseRequest()
+static int game_checkPauseRequest()
 {
-	getPlayerInput();
+	player_getInput();
 		
 	if (engine.keyState[KEY_ESCAPE])
 	{
-		engine.paused = false;
-		engine.done = 1;
+		engine.paused = 0;
 		player.shield = 0;
-		return true;
+		return 1;
 	}
 	
 	if (engine.keyState[KEY_PAUSE])
 	{
-		engine.paused = false;
+		engine.paused = 0;
 		engine.keyState[KEY_PAUSE] = 0;
 	}
 
-	return false;
+	return 0;
 }
 
-bool game_collision(float x0, float y0, int w0, int h0, float x2, float y2, int w1, int h1)
+int game_collision(float x0, float y0, int w0, int h0, float x2, float y2, int w1, int h1)
 {
 	float x1 = x0 + w0;
 	float y1 = y0 + h0;
@@ -2008,15 +2128,66 @@ bool game_collision(float x0, float y0, int w0, int h0, float x2, float y2, int
 	return !(x1<x2 || x3<x0 || y1<y2 || y3<y0);
 }
 
+/*
+The game over screen :(
+*/
+static void game_showGameOver()
+{
+	screen_flushBuffer();
+	gfx_free();
+	SDL_FillRect(gfx_background, NULL, black);
+
+	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
+	engine.gameSection = SECTION_INTERMISSION;
+
+	SDL_Surface *gameover = gfx_loadImage("gfx/gameover.png");
+
+	screen_clear(black);
+	renderer_update();
+	screen_clear(black);
+	SDL_Delay(1000);
+
+	audio_playMusic("music/death.ogg", -1);
+
+	int x = (screen->w - gameover->w) / 2;
+	int y = (screen->h - gameover->h) / 2;
+
+	renderer_update();
+
+	player_flushInput();
+	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
+
+	while (1)
+	{
+		player_getInput();
+
+		if (engine.keyState[KEY_FIRE] || engine.keyState[KEY_ALTFIRE])
+			break;
+
+		renderer_update();
+
+		screen_unBuffer();
+		x = ((screen->w - gameover->w) / 2) - RANDRANGE(-2, 2);
+		y = ((screen->h - gameover->h) / 2)  - RANDRANGE(-2, 2);
+		screen_blit(gameover, x,  y);
+
+		game_delayFrame();
+	}
+
+	SDL_FreeSurface(gameover);
+	audio_haltMusic();
+	screen_flushBuffer();
+}
+
 int game_mainLoop()
 {
-	resetLists();
+	engine_resetLists();
 
-	setMission(game.area);
-	missionBriefScreen();
+	mission_set(game.area);
+	mission_showStartScreen();
 
 	cargo_init();
-	initPlayer();
+	player_init();
 	aliens_init();
 
 	// specific for Phoebe being captured!
@@ -2024,7 +2195,7 @@ int game_mainLoop()
 		game.hasWingMate1 = 1;
 
 	if (game.area == MISN_ELAMALE)
-		aliens[ALIEN_KLINE].active = false;
+		aliens[ALIEN_KLINE].active = 0;
 
 	for (int i = 0 ; i < engine.maxAliens ; i++)
 		alien_add();
@@ -2051,8 +2222,8 @@ int game_mainLoop()
 		case MISN_ELLESH:
 		case MISN_MARS:
 		case MISN_VENUS:
-			aliens[ALIEN_PHOEBE].active = false;
-			aliens[ALIEN_URSULA].active = false;
+			aliens[ALIEN_PHOEBE].active = 0;
+			aliens[ALIEN_URSULA].active = 0;
 			break;
 	}
 
@@ -2070,7 +2241,7 @@ int game_mainLoop()
 			aliens[ALIEN_KLINE] = alien_defs[CD_KLINE];
 			aliens[ALIEN_KLINE].owner = &aliens[ALIEN_KLINE];
 			aliens[ALIEN_KLINE].target = &player;
-			aliens[ALIEN_KLINE].active = true;
+			aliens[ALIEN_KLINE].active = 1;
 			aliens[ALIEN_KLINE].x = player.x + 1000;
 			aliens[ALIEN_KLINE].y = player.y;
 			player_setTarget(ALIEN_KLINE);
@@ -2084,7 +2255,7 @@ int game_mainLoop()
 				aliens[ALIEN_BOSS].owner = &aliens[ALIEN_BOSS];
 				aliens[ALIEN_BOSS].target = &aliens[ALIEN_BOSS];
 				aliens[ALIEN_BOSS].shield = 1000;
-				aliens[ALIEN_BOSS].active = true;
+				aliens[ALIEN_BOSS].active = 1;
 				aliens[ALIEN_BOSS].x = player.x - 1000;
 				aliens[ALIEN_BOSS].y = player.y;
 				player_setTarget(ALIEN_BOSS);
@@ -2136,7 +2307,7 @@ int game_mainLoop()
 			break;
 	}
 
-	clearInfoLines();
+	info_clearLines();
 
 	events_init();
 
@@ -2159,11 +2330,11 @@ int game_mainLoop()
 
 	for (int i = 0 ; i < 3 ; i++)
 	{
-		if ((currentMission.primaryType[i] == M_DESTROY_TARGET_TYPE) &&
-				(currentMission.target1[i] == CD_ANY))
-			allowableAliens = currentMission.targetValue1[i];
+		if ((mission.primaryType[i] == M_DESTROY_TARGET_TYPE) &&
+				(mission.target1[i] == CD_ANY))
+			allowableAliens = mission.targetValue1[i];
 
-		if (currentMission.primaryType[i] == M_DESTROY_ALL_TARGETS)
+		if (mission.primaryType[i] == M_DESTROY_ALL_TARGETS)
 			allowableAliens = 999999999;
 	}
 
@@ -2183,18 +2354,18 @@ int game_mainLoop()
 
 	engine.keyState[KEY_FIRE] = 0;
 	engine.keyState[KEY_ALTFIRE] = 0;
-	flushInput();
+	player_flushInput();
 
 	while (engine.done != 1)
 	{
 		renderer_update();
 
-		if ((allMissionsCompleted()) && (engine.missionCompleteTimer == 0))
+		if ((mission_checkCompleted()) && (engine.missionCompleteTimer == 0))
 		{
 			engine.missionCompleteTimer = SDL_GetTicks() + 4000;
 		}
 
-		if ((missionFailed()) && (engine.missionCompleteTimer == 0))
+		if ((mission_checkFailed()) && (engine.missionCompleteTimer == 0))
 		{
 			if (game.area != MISN_MOEBO)
 				engine.missionCompleteTimer = SDL_GetTicks() + 4000;
@@ -2207,9 +2378,9 @@ int game_mainLoop()
 			{
 				if (SDL_GetTicks() >= engine.missionCompleteTimer)
 				{
-					if ((!missionFailed()) && (game.area != MISN_VENUS))
+					if ((!mission_checkFailed()) && (game.area != MISN_VENUS))
 					{
-						leaveSector();
+						player_leaveSector();
 						if ((engine.done == 2) &&
 							(game.area != MISN_DORIM) &&
 							(game.area != MISN_SIVEDI))
@@ -2258,7 +2429,7 @@ int game_mainLoop()
 				}
 				else
 				{
-					getPlayerInput();
+					player_getInput();
 				}
 			}
 			else
@@ -2273,7 +2444,7 @@ int game_mainLoop()
 		}
 		else
 		{
-			getPlayerInput();
+			player_getInput();
 		}
 
 		screen_unBuffer();
@@ -2302,7 +2473,8 @@ int game_mainLoop()
 				game_delayFrame();
 			}
 
-			audio_resumeMusic();
+			if (!engine.done)
+				audio_resumeMusic();
 		}
 
 		if ((game.area == MISN_MARS) && (engine.addAliens > -1))
@@ -2314,14 +2486,14 @@ int game_mainLoop()
 				// but I'm not entirely sure what the original intention was.
 				// For now, I've set the range to [800, 1500], which
 				// approximately replicates the original's results.
-				collectable_add(RANDRANGE(800, 1500),
+				collectable_add(screen->w + RANDRANGE(0, 700),
 					RANDRANGE(-screen->h / 3, (4 * screen->h) / 3), P_MINE, 25,
-					180 + rand() % 60);
+					180 * screen->w / 800 + RANDRANGE(0, 60));
 		}
 
 		if (engine.addAliens > -1)
 		{
-			WRAP_ADD(engine.addAliens, -1, 0, currentMission.addAliens);
+			WRAP_ADD(engine.addAliens, -1, 0, mission.addAliens);
 			if ((engine.addAliens == 0) && (allowableAliens > 0))
 			{
 				allowableAliens -= alien_add();
@@ -2353,10 +2525,10 @@ int game_mainLoop()
 
 	screen_flushBuffer();
 
-	if ((player.shield > 0) && (!missionFailed()))
+	if ((player.shield > 0) && (!mission_checkFailed()))
 	{
 		if (game.area < MISN_VENUS)
-			missionFinishedScreen();
+			mission_showFinishedScreen();
 
 		switch (game.area)
 		{
@@ -2377,14 +2549,14 @@ int game_mainLoop()
 				cutscene_init(6);
 				break;
 			case MISN_VENUS:
-				doCredits();
+				title_showCredits();
 				break;
 		}
 		
 		if (game.area < MISN_VENUS)
 		{
-			updateSystemStatus();
-			saveGame(0);
+			intermission_updateSystemStatus();
+			save(0);
 		}
 
 		rtn = 1;
@@ -2394,11 +2566,11 @@ int game_mainLoop()
 	}
 	else
 	{
-		gameover();
+		game_showGameOver();
 		rtn = 0;
 	}
 
-	exitPlayer();
+	player_exit();
 
 	return rtn;
 }
