@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2012, 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,17 +17,29 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include "SDL.h"
 
-object player;
-bool player_chargerFired = false;
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "screen.h"
+#include "weapons.h"
+#include "window.h"
+
+Object player;
+int player_chargerFired = 0;
 
 /*
 Initialises the player for a new game.
 */
-void initPlayer()
+void player_init()
 {
-	player.active = true;
+	player.active = 1;
 	player.x = screen->w / 2;
 	player.y = screen->h / 2;
 	player.speed = 2;
@@ -45,12 +57,12 @@ void initPlayer()
 
 	player.weaponType[0] = W_PLAYER_WEAPON;
 
-	if (weapon[W_PLAYER_WEAPON].ammo[0] < game.minPlasmaOutput)
-		weapon[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
-	if (weapon[W_PLAYER_WEAPON].damage < game.minPlasmaDamage)
-		weapon[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
-	if (weapon[W_PLAYER_WEAPON].reload[0] > rate2reload[game.minPlasmaRate])
-		weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
+	if (weapons[W_PLAYER_WEAPON].ammo[0] < game.minPlasmaOutput)
+		weapons[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
+	if (weapons[W_PLAYER_WEAPON].damage < game.minPlasmaDamage)
+		weapons[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
+	if (weapons[W_PLAYER_WEAPON].reload[0] > rate2reload[game.minPlasmaRate])
+		weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
 
 	player.hit = 0;
 
@@ -74,7 +86,7 @@ void player_checkShockDamage(float x, float y)
 	float distY = fabsf(y - player.y);
 
 	// Don't let the player be hurt by an explosion after they have completed
-	// all the mission objectives. That would be *really* annoying!
+	// all the mission Objectives. That would be *really* annoying!
 	if ((engine.cheatShield) || (engine.missionCompleteTimer != 0))
 		return;
 
@@ -93,15 +105,15 @@ void player_checkShockDamage(float x, float y)
 	}
 }
 
-void exitPlayer()
+void player_exit()
 {
-	player_chargerFired = false;
+	player_chargerFired = 0;
 
 	if ((player.weaponType[1] == W_CHARGER) || (player.weaponType[1] == W_LASER))
 		player.ammo[1] = 0;
 }
 
-void flushInput()
+void player_flushInput()
 {
 	for (int i = 0; i < KEY_LAST; i++)
 		engine.keyState[i] = 0;
@@ -109,7 +121,7 @@ void flushInput()
 	while (SDL_PollEvent(&engine.event)){}
 }
 
-static enum keys mapkey(uint32_t code) {
+static enum keys mapkey(int code) {
 	switch (code) {
 		case SDLK_UP:
 		case SDLK_KP_8:
@@ -138,6 +150,8 @@ static enum keys mapkey(uint32_t code) {
 		case SDLK_1:
 		case SDLK_3:
 		case SDLK_KP_0:
+		case SDLK_HOME:
+		case SDLK_END:
 			return KEY_FIRE;
 		case SDLK_SPACE:
 		case SDLK_x:
@@ -145,6 +159,8 @@ static enum keys mapkey(uint32_t code) {
 		case SDLK_PERIOD:
 		case SDLK_2:
 		case SDLK_KP_1:
+		case SDLK_PAGEUP:
+		case SDLK_PAGEDOWN:
 			return KEY_ALTFIRE;
 		case SDLK_LSHIFT:
 		case SDLK_RSHIFT:
@@ -154,10 +170,12 @@ static enum keys mapkey(uint32_t code) {
 		case SDLK_KP_9:
 			return KEY_SWITCH;
 		case SDLK_p:
+		case SDLK_PAUSE:
 			return KEY_PAUSE;
 		case SDLK_ESCAPE:
 		case SDLK_q:
 		case SDLK_BACKSPACE:
+		case SDLK_DELETE:
 			return KEY_ESCAPE;
 		case SDLK_F11:
 			return KEY_FULLSCREEN;
@@ -166,7 +184,7 @@ static enum keys mapkey(uint32_t code) {
 	}
 }
 
-void getPlayerInput()
+void player_getInput()
 {
 	while (SDL_PollEvent(&engine.event))
 	{
@@ -188,7 +206,7 @@ void getPlayerInput()
 				engine.keyState[mapkey(engine.event.key.keysym.sym)] = 1;
 
 				if (engine.gameSection != SECTION_GAME)
-					engine.paused = false;
+					engine.paused = 0;
 
 				break;
 
@@ -233,17 +251,17 @@ void getPlayerInput()
 				break;
 
 			case SDL_JOYAXISMOTION:
-				static bool prevjoyup, prevjoydown, prevjoyleft, prevjoyright;
+				static int prevjoyup, prevjoydown, prevjoyleft, prevjoyright;
 				if (engine.event.jaxis.axis & 1) {
-					bool joyup = engine.event.jaxis.value < -16384;
-					bool joydown = engine.event.jaxis.value >= 16384;
+					int joyup = engine.event.jaxis.value < -16384;
+					int joydown = engine.event.jaxis.value >= 16384;
 					if(joyup != prevjoyup)
 						engine.keyState[KEY_UP] = prevjoyup = joyup;
 					if(joydown != prevjoydown)
 						engine.keyState[KEY_DOWN] = prevjoydown = joydown;
 				} else {
-					bool joyleft = engine.event.jaxis.value < -16384;
-					bool joyright = engine.event.jaxis.value >= 16384;
+					int joyleft = engine.event.jaxis.value < -16384;
+					int joyright = engine.event.jaxis.value >= 16384;
 					if(joyleft != prevjoyleft)
 						engine.keyState[KEY_LEFT] = prevjoyleft = joyleft;
 					if(joyright != prevjoyright)
@@ -254,14 +272,14 @@ void getPlayerInput()
 			case SDL_WINDOWEVENT:
 				if (engine.autoPause &&
 						(engine.event.window.event == SDL_WINDOWEVENT_FOCUS_LOST))
-					engine.paused = true;
+					engine.paused = 1;
 				break;
 		}
 
 		if (engine.keyState[KEY_FULLSCREEN])
 		{
 			engine.fullScreen = !engine.fullScreen;
-			SDL_SetWindowFullscreen(window, engine.fullScreen ? SDL_WINDOW_FULLSCREEN_DESKTOP : 0);
+			SDL_SetWindowFullscreen(window, engine.fullScreen ? FULLSCREEN : 0);
 			engine.keyState[KEY_FULLSCREEN] = 0;
 		}
 	}
@@ -292,7 +310,7 @@ void getPlayerInput()
 
 }
 
-void leaveSector()
+void player_leaveSector()
 {
 	engine.keyState[KEY_UP] = 0;
 	engine.keyState[KEY_DOWN] = 0;
