@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,15 +20,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef PLAYER_H
 #define PLAYER_H
 
-extern object player;
-extern bool player_chargerFired;
+#include "defs.h"
+#include "structs.h"
 
-extern void initPlayer();
+extern Object player;
+extern int player_chargerFired;
+
+void player_init();
 void player_setTarget(int index);
 void player_checkShockDamage(float x, float y);
-extern void exitPlayer();
-extern void flushInput();
-extern void getPlayerInput();
-extern void leaveSector();
+void player_exit();
+void player_flushInput();
+void player_getInput();
+void player_leaveSector();
 
 #endif
