@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,11 +20,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SCREEN_H
 #define SCREEN_H
 
+#include "SDL.h"
+
+#include "defs.h"
 #include "structs.h"
 
 extern SDL_Surface *screen;
-extern bRect *screen_bufferHead;
-extern bRect *screen_bufferTail;
+extern LinkedRect *screen_bufferHead;
+extern LinkedRect *screen_bufferTail;
 
 void screen_blit(SDL_Surface *image, int x, int y);
 void screen_blitText(int i);
