@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,9 +17,25 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdlib.h>
 
-bool ship_collision(object *ship, object *otherShip)
+#include "SDL.h"
+
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "bullet.h"
+#include "engine.h"
+#include "explosion.h"
+#include "game.h"
+#include "info.h"
+#include "player.h"
+#include "screen.h"
+#include "weapons.h"
+
+int ship_collision(Object *ship, Object *otherShip)
 {
 	float x0 = ship->x;
 	float y0 = ship->y;
@@ -43,18 +59,18 @@ bool ship_collision(object *ship, object *otherShip)
 /*
 Fill in later...
 */
-void ship_fireBullet(object *ship, int weaponType)
+void ship_fireBullet(Object *ship, int weaponIndex)
 {
-	if (ship->reload[weaponType] > 0)
+	int y = (ship->image[0]->h) / 5;
+	Object *theWeapon = &weapons[ship->weaponType[weaponIndex]];
+
+	if (ship->reload[weaponIndex] > 0)
 		return;
 
-	int y = (ship->image[0]->h) / 5;
-
 	// Remove some ammo from the player
-	if ((ship == &player) && (weaponType == 1) && (!engine.cheatAmmo))
-		player.ammo[1]--;
-
-	object *theWeapon = &weapon[ship->weaponType[weaponType]];
+	if ((ship == &player) && (player.weaponType[weaponIndex] != W_LASER) &&
+			(player.ammo[weaponIndex] > 0) && (!engine.cheatAmmo))
+		player.ammo[weaponIndex]--;
 
 	switch(theWeapon->id)
 	{
@@ -113,25 +129,18 @@ void ship_fireBullet(object *ship, int weaponType)
 
 	// Reset the weapon reload time. Double it if it is not friendly or
 	// a boss or Kline
-	ship->reload[weaponType] = theWeapon->reload[0];
+	ship->reload[weaponIndex] = theWeapon->reload[0];
 	if ((ship->flags & FL_WEAPCO) && (ship != &aliens[ALIEN_BOSS]) &&
 			(ship != &aliens[ALIEN_KLINE]) && (theWeapon->id != W_LASER))
-		ship->reload[weaponType] *= 2;
+		ship->reload[weaponIndex] *= 2;
 
-	if ((engine.cheatAmmo) || (theWeapon->id == WT_LASER))
-		return;
-
-	if ((ship == &player) && (weaponType == 0))
+	if ((ship == &player) && (weaponIndex == 0))
 	{
-		if (player.ammo[0] > 0)
+		if (player.ammo[weaponIndex] <= 0)
 		{
-			player.ammo[0]--;
-			if (player.ammo[0] <= 0)
-			{
-				weapon[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
-				weapon[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
-				weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
-			}
+			weapons[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
+			weapons[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
+			weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
 		}
 	}
 }
@@ -139,7 +148,7 @@ void ship_fireBullet(object *ship, int weaponType)
 /*
 Fill in later...
 */
-void ship_fireRay(object *ship)
+void ship_fireRay(Object *ship)
 {
 	SDL_Rect ray;
 
@@ -171,7 +180,7 @@ void ship_fireRay(object *ship)
 				{
 					if (player.shield - 1 <= engine.lowShield)
 					{
-						setInfoLine("!!! WARNING: SHIELD LOW !!!", FONT_RED);
+						info_setLine("!!! WARNING: SHIELD LOW !!!", FONT_RED);
 					}
 				}
 				player.shield--;
@@ -198,7 +207,7 @@ void ship_fireRay(object *ship)
 			if (game_collision(aliens[i].x, aliens[i].y, aliens[i].image[0]->w,
 					aliens[i].image[0]->h, ray.x, ray.y, ray.w, ray.h))
 			{
-				alien_hurt(&aliens[i], ship->owner, 1, false);
+				alien_hurt(&aliens[i], ship->owner, 1, 0);
 			}
 		}
 	}
