@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,8 +18,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef SHIP_H
 #define SHIP_H
 
-bool ship_collision(object *ship, object *otherShip);
-void ship_fireBullet(object *ship, int weaponType);
-void ship_fireRay(object *ship);
+#include "defs.h"
+#include "structs.h"
+
+int ship_collision(Object *ship, Object *otherShip);
+void ship_fireBullet(Object *ship, int weaponType);
+void ship_fireRay(Object *ship);
 
 #endif
