@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,36 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdio.h>
+
+#include "SDL.h"
+
+#include "defs.h"
+#include "structs.h"
+
+#include "engine.h"
+#include "game.h"
+#include "gfx.h"
+#include "intermission.h"
+#include "player.h"
+#include "save.h"
+#include "screen.h"
+#include "weapons.h"
+
+typedef struct ShopItem_ {
+
+	int x, y;
+	int price;
+	char name[50];
+	char description[255];
+	int image;
+
+} ShopItem;
+
+static const int shop_w = 600;
+static const int shop_x = SCREEN_WIDTH / 2 - shop_w / 2;
+static const int shop_h = 336;
+static const int shop_y = intermission_ycenter - shop_h / 2;
 
 static ShopItem shopItems[SHOP_MAX];
 static int shopSelectedItem;
@@ -33,31 +62,31 @@ static void drawSecondaryWeaponSurface()
 	switch (player.weaponType[1])
 	{
 		case W_NONE:
-			strcpy(description, "Type : None");
+			strcpy(description, "None");
 			break;
 		case W_ROCKETS:
-			strcpy(description, "Type : Rockets");
+			strcpy(description, "Rockets");
 			break;
 		case W_DOUBLE_ROCKETS:
-			strcpy(description, "Type : Dbl Rockets");
+			strcpy(description, "Dbl Rockets");
 			break;
 		case W_MICRO_ROCKETS:
-			strcpy(description, "Type : Micro Rockets");
+			strcpy(description, "Micro Rockets");
 			break;
 		case W_LASER:
-			strcpy(description, "Type : Laser");
+			strcpy(description, "Laser");
 			break;
 		case W_CHARGER:
-			strcpy(description, "Type : Charger");
+			strcpy(description, "Charger");
 			break;
 		case W_HOMING_MISSILE:
-			strcpy(description, "Type : Homing Missile");
+			strcpy(description, "Homing Missile");
 			break;
 		case W_DOUBLE_HOMING_MISSILES:
-			strcpy(description, "Type : Dbl Homing Missiles");
+			strcpy(description, "Dbl Homing Missiles");
 			break;
 		case W_MICRO_HOMING_MISSILES:
-			strcpy(description, "Type : Mcr Homing Missiles");
+			strcpy(description, "Mcr Homing Missiles");
 			break;
 	}
 	gfx_renderString(description, 10, 22, FONT_WHITE, 0, gfx_shopSprites[2]);
@@ -91,14 +120,14 @@ static void adjustShopPrices()
 		shopItems[SHOP_PLASMA_MIN_OUTPUT].price = 1500 * (game.minPlasmaOutput + 1);
 		shopItems[SHOP_PLASMA_MIN_DAMAGE].price = 1500 * (game.minPlasmaDamage + 1);
 		shopItems[SHOP_PLASMA_MIN_RATE].price = 1500 * (game.minPlasmaRate + 1);
-	}
 
-	if (game.maxPlasmaOutput <= game.minPlasmaOutput)
-		shopItems[SHOP_PLASMA_MIN_OUTPUT].price += shopItems[SHOP_PLASMA_MAX_OUTPUT].price;
-	if (game.maxPlasmaDamage <= game.minPlasmaDamage)
-		shopItems[SHOP_PLASMA_MIN_DAMAGE].price += shopItems[SHOP_PLASMA_MAX_DAMAGE].price;
-	if (game.maxPlasmaRate <= game.minPlasmaRate)
-		shopItems[SHOP_PLASMA_MIN_RATE].price += shopItems[SHOP_PLASMA_MAX_RATE].price;
+		if (game.maxPlasmaOutput <= game.minPlasmaOutput)
+			shopItems[SHOP_PLASMA_MIN_OUTPUT].price += shopItems[SHOP_PLASMA_MAX_OUTPUT].price;
+		if (game.maxPlasmaDamage <= game.minPlasmaDamage)
+			shopItems[SHOP_PLASMA_MIN_DAMAGE].price += shopItems[SHOP_PLASMA_MAX_DAMAGE].price;
+		if (game.maxPlasmaRate <= game.minPlasmaRate)
+			shopItems[SHOP_PLASMA_MIN_RATE].price += shopItems[SHOP_PLASMA_MAX_RATE].price;
+	}
 
 	shopItems[SHOP_PLASMA_MAX_AMMO].price = (10 * (game.maxPlasmaAmmo - 75));
 	shopItems[SHOP_ROCKET_MAX_AMMO].price = (25 * game.maxRocketAmmo);
@@ -143,19 +172,19 @@ static void drawShop()
 		}
 	}
 
-	gfx_shopSprites[SHOP_S_PRIMARY] = gfx_createSurface(246, 91);
-	gfx_shopSprites[SHOP_S_POWERUP] = gfx_createSurface(246, 91);
-	gfx_shopSprites[SHOP_S_SECONDARY] = gfx_createSurface(246, 91);
+	gfx_shopSprites[SHOP_S_PRIMARY] = gfx_createSurface(190, 91);
+	gfx_shopSprites[SHOP_S_POWERUP] = gfx_createSurface(190, 91);
+	gfx_shopSprites[SHOP_S_SECONDARY] = gfx_createSurface(190, 91);
 
-	gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 245, 90, 0x00, 0x00, 0x55);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 245, 20, 0x00, 0x00, 0x99);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 245, 90, 0x00, 0x00, 0x55);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 245, 20, 0x00, 0x00, 0x99);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 245, 90, 0x00, 0x00, 0x55);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 245, 20, 0x00, 0x00, 0x99);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 189, 90, 0x00, 0x00, 0x55);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 189, 20, 0x00, 0x00, 0x99);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 189, 90, 0x00, 0x00, 0x55);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 189, 20, 0x00, 0x00, 0x99);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 189, 90, 0x00, 0x00, 0x55);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 189, 20, 0x00, 0x00, 0x99);
 
-	gfx_shopSprites[SHOP_S_SHIP_INFO] = gfx_createAlphaRect(601, 101, 0x00, 0x00, 0x00);
-	gfx_drawRect(gfx_shopSprites[SHOP_S_SHIP_INFO], 0, 0, 600, 100, 0x00, 0x00, 0x33);
+	gfx_shopSprites[SHOP_S_SHIP_INFO] = gfx_createAlphaRect(601, 41, 0x00, 0x00, 0x00);
+	gfx_drawRect(gfx_shopSprites[SHOP_S_SHIP_INFO], 0, 0, 600, 40, 0x00, 0x00, 0x33);
 
 	switch (shopSelectedItem)
 	{
@@ -170,48 +199,48 @@ static void drawShop()
 		case SHOP_PLASMA_MAX_DAMAGE:
 		case SHOP_PLASMA_MAX_RATE:
 		case SHOP_PLASMA_MAX_AMMO:
-			gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 189, 90, 0x55, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_POWERUP], 0, 0, 189, 20, 0x99, 0x00, 0x00);
 			break;
 		case SHOP_PLASMA_MIN_OUTPUT:
 		case SHOP_PLASMA_MIN_DAMAGE:
 		case SHOP_PLASMA_MIN_RATE:
-			gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 189, 90, 0x55, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_PRIMARY], 0, 0, 189, 20, 0x99, 0x00, 0x00);
 			break;
 		case SHOP_PLASMA_AMMO:
 		case SHOP_ROCKET_AMMO:
-			gfx_drawRect(gfx_shopSprites[SHOP_S_SHIP_INFO], 0, 0, 600, 100, 0x33, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_SHIP_INFO], 0, 0, 600, 40, 0x33, 0x00, 0x00);
 			break;
 		default:
-			gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 245, 90, 0x55, 0x00, 0x00);
-			gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 245, 20, 0x99, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 189, 90, 0x55, 0x00, 0x00);
+			gfx_drawRect(gfx_shopSprites[SHOP_S_SECONDARY], 0, 0, 189, 20, 0x99, 0x00, 0x00);
 			break;
 	}
 
 	strcpy(description, "");
 
 	gfx_renderString("Primary Weapon", 10, 3, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_PRIMARY]);
-	sprintf(description, "Plasma Cannons : %d", game.minPlasmaOutput);
+	sprintf(description, "Cannons : %d", game.minPlasmaOutput);
 	gfx_renderString(description, 10, 22, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_PRIMARY]);
-	sprintf(description, "Plasma Power   : Stage %d",
+	sprintf(description, "Power   : Stage %d",
 		game.minPlasmaDamage);
 	gfx_renderString(description, 10, 37, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_PRIMARY]);
-	sprintf(description, "Cooler         : Stage %d",
+	sprintf(description, "Cooling : Stage %d",
 		game.minPlasmaRate);
 	gfx_renderString(description, 10, 52, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_PRIMARY]);
 
 	gfx_renderString("Powerup Weapon", 10, 3, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_POWERUP]);
-	sprintf(description, "Plasma Output    : Stage %d",
+	sprintf(description, "Splitter  : Stage %d",
 		game.maxPlasmaOutput);
 	gfx_renderString(description, 10, 22, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_POWERUP]);
-	sprintf(description, "Plasma Condensor : Stage %d",
+	sprintf(description, "Condensor : Stage %d",
 		game.maxPlasmaDamage);
 	gfx_renderString(description, 10, 37, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_POWERUP]);
-	sprintf(description, "Liquid Nitrogen  : Stage %d",
+	sprintf(description, "L.Nitrogen: Stage %d",
 		game.maxPlasmaRate);
 	gfx_renderString(description, 10, 52, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_POWERUP]);
-	sprintf(description, "Plasma Capacity  : %d", game.maxPlasmaAmmo);
+	sprintf(description, "Capacity  : %d", game.maxPlasmaAmmo);
 	gfx_renderString(description, 10, 67, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_POWERUP]);
 
 	drawSecondaryWeaponSurface();
@@ -236,23 +265,23 @@ static void drawShop()
 
 	for (int i = 0 ; i < icons ; i++)
 	{
-		gfx_blit(gfx_sprites[shopItems[i].image], shopItems[i].x - 90,
-			shopItems[i].y - 178, gfx_shopSprites[SHOP_S_CATALOG]);
+		gfx_blit(gfx_sprites[shopItems[i].image], shopItems[i].x + 10 - shop_x,
+			shopItems[i].y - shop_y - 48, gfx_shopSprites[SHOP_S_CATALOG]);
 	}
 
-	sprintf(description, "Shield Units : %d", player.maxShield);
-	gfx_renderString(description, 10, 4, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
-	sprintf(description, "Cash : $%d", game.cash);
-	gfx_renderString(description, 10, 80, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
+	sprintf(description, "Shield : %d", player.maxShield);
+	gfx_renderString(description, 10, 6, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
+	sprintf(description, "  Cash : $%d", game.cash);
+	gfx_renderString(description, 10, 22, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
 	sprintf(description, "Plasma Cells : %.3d", player.ammo[0]);
-	gfx_renderString(description, 430, 4, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
-	sprintf(description, "Rockets : %.3d", player.ammo[1]);
-	gfx_renderString(description, 475, 80, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
+	gfx_renderString(description, 430, 6, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
+	sprintf(description, "Rockets :  %.2d", player.ammo[1]);
+	gfx_renderString(description, 475, 22, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_SHIP_INFO]);
 
 	gfx_shopSprites[SHOP_S_ITEM_INFO] = gfx_createSurface(601, 56);
 	gfx_drawRect(gfx_shopSprites[SHOP_S_ITEM_INFO], 0, 0, 600, 35, 0x00, 0x99, 0x00);
 	gfx_drawRect(gfx_shopSprites[SHOP_S_ITEM_INFO], 0, 20, 600, 35, 0x00, 0x33, 0x00);
-	gfx_renderString("Information", 5, 4, FONT_WHITE, 0, gfx_shopSprites[5]);
+	gfx_renderString("Information", 5, 4, FONT_WHITE, 0, gfx_shopSprites[SHOP_S_ITEM_INFO]);
 
 	switch (shopSelectedItem)
 	{
@@ -311,7 +340,7 @@ static void drawShop()
 	}
 }
 
-void initShop()
+void shop_init()
 {
 	/* ----------- Temporary Items ----------- */
 
@@ -430,56 +459,56 @@ void initShop()
 		"Fires several small homing missiles (max %i missiles)", maxMicroHoming);
 	shopItems[SHOP_MICRO_HOMING_MISSILES].image = 25;
 
-	shopItems[SHOP_PLASMA_MAX_OUTPUT].x = 100;
-	shopItems[SHOP_PLASMA_MAX_OUTPUT].y = 200;
+	shopItems[SHOP_PLASMA_MAX_OUTPUT].x = shop_x;
+	shopItems[SHOP_PLASMA_MAX_OUTPUT].y = shop_y + 70;
 
-	shopItems[SHOP_PLASMA_MAX_DAMAGE].x = 150;
-	shopItems[SHOP_PLASMA_MAX_DAMAGE].y = 200;
+	shopItems[SHOP_PLASMA_MAX_DAMAGE].x = shop_x + 50;
+	shopItems[SHOP_PLASMA_MAX_DAMAGE].y = shop_y + 70;
 
-	shopItems[SHOP_PLASMA_MAX_RATE].x = 200;
-	shopItems[SHOP_PLASMA_MAX_RATE].y = 200;
+	shopItems[SHOP_PLASMA_MAX_RATE].x = shop_x + 100;
+	shopItems[SHOP_PLASMA_MAX_RATE].y = shop_y + 70;
 
-	shopItems[SHOP_PLASMA_MIN_OUTPUT].x = 100;
-	shopItems[SHOP_PLASMA_MIN_OUTPUT].y = 260;
+	shopItems[SHOP_PLASMA_MIN_OUTPUT].x = shop_x;
+	shopItems[SHOP_PLASMA_MIN_OUTPUT].y = shop_y + 130;
 
-	shopItems[SHOP_PLASMA_MIN_DAMAGE].x = 150;
-	shopItems[SHOP_PLASMA_MIN_DAMAGE].y = 260;
+	shopItems[SHOP_PLASMA_MIN_DAMAGE].x = shop_x + 50;
+	shopItems[SHOP_PLASMA_MIN_DAMAGE].y = shop_y + 130;
 
-	shopItems[SHOP_PLASMA_MIN_RATE].x = 200;
-	shopItems[SHOP_PLASMA_MIN_RATE].y = 260;
+	shopItems[SHOP_PLASMA_MIN_RATE].x = shop_x + 100;
+	shopItems[SHOP_PLASMA_MIN_RATE].y = shop_y + 130;
 
-	shopItems[SHOP_PLASMA_AMMO].x = 350;
-	shopItems[SHOP_PLASMA_AMMO].y = 200;
+	shopItems[SHOP_PLASMA_AMMO].x = shop_x + 250;
+	shopItems[SHOP_PLASMA_AMMO].y = shop_y + 70;
 
-	shopItems[SHOP_ROCKET_AMMO].x = 400;
-	shopItems[SHOP_ROCKET_AMMO].y = 200;
+	shopItems[SHOP_ROCKET_AMMO].x = shop_x + 300;
+	shopItems[SHOP_ROCKET_AMMO].y = shop_y + 70;
 
-	shopItems[SHOP_PLASMA_MAX_AMMO].x = 450;
-	shopItems[SHOP_PLASMA_MAX_AMMO].y = 200;
+	shopItems[SHOP_PLASMA_MAX_AMMO].x = shop_x + 350;
+	shopItems[SHOP_PLASMA_MAX_AMMO].y = shop_y + 70;
 
-	shopItems[SHOP_ROCKET_MAX_AMMO].x = 500;
-	shopItems[SHOP_ROCKET_MAX_AMMO].y = 200;
+	shopItems[SHOP_ROCKET_MAX_AMMO].x = shop_x + 400;
+	shopItems[SHOP_ROCKET_MAX_AMMO].y = shop_y + 70;
 
-	shopItems[SHOP_DOUBLE_ROCKETS].x = 350;
-	shopItems[SHOP_DOUBLE_ROCKETS].y = 260;
+	shopItems[SHOP_DOUBLE_ROCKETS].x = shop_x + 250;
+	shopItems[SHOP_DOUBLE_ROCKETS].y = shop_y + 130;
 
-	shopItems[SHOP_MICRO_ROCKETS].x = 400;
-	shopItems[SHOP_MICRO_ROCKETS].y = 260;
+	shopItems[SHOP_MICRO_ROCKETS].x = shop_x + 300;
+	shopItems[SHOP_MICRO_ROCKETS].y = shop_y + 130;
 
-	shopItems[SHOP_LASER].x = 450;
-	shopItems[SHOP_LASER].y = 260;
+	shopItems[SHOP_LASER].x = shop_x + 350;
+	shopItems[SHOP_LASER].y = shop_y + 130;
 
-	shopItems[SHOP_HOMING_MISSILE].x = 500;
-	shopItems[SHOP_HOMING_MISSILE].y = 260;
+	shopItems[SHOP_HOMING_MISSILE].x = shop_x + 400;
+	shopItems[SHOP_HOMING_MISSILE].y = shop_y + 130;
 
-	shopItems[SHOP_CHARGER].x = 550;
-	shopItems[SHOP_CHARGER].y = 260;
+	shopItems[SHOP_CHARGER].x = shop_x + 450;
+	shopItems[SHOP_CHARGER].y = shop_y + 130;
 
-	shopItems[SHOP_DOUBLE_HOMING_MISSILES].x = 600;
-	shopItems[SHOP_DOUBLE_HOMING_MISSILES].y = 260;
+	shopItems[SHOP_DOUBLE_HOMING_MISSILES].x = shop_x + 500;
+	shopItems[SHOP_DOUBLE_HOMING_MISSILES].y = shop_y + 130;
 
-	shopItems[SHOP_MICRO_HOMING_MISSILES].x = 650;
-	shopItems[SHOP_MICRO_HOMING_MISSILES].y = 260;
+	shopItems[SHOP_MICRO_HOMING_MISSILES].x = shop_x + 550;
+	shopItems[SHOP_MICRO_HOMING_MISSILES].y = shop_y + 130;
 
  	shopSelectedItem = -1;
 
@@ -708,8 +737,11 @@ static void buy(int i)
 			shop_sellSecondaryWeapon();
 			player.weaponType[1] = W_LASER;
 
-			while (game.maxRocketAmmo > 5)
-				sell(SHOP_ROCKET_MAX_AMMO);
+			if (game.difficulty != DIFFICULTY_ORIGINAL)
+			{
+				while (game.maxRocketAmmo > 5)
+					sell(SHOP_ROCKET_MAX_AMMO);
+			}
 			while (player.ammo[1] > 0)
 				sell(SHOP_ROCKET_AMMO);
 
@@ -741,8 +773,11 @@ static void buy(int i)
 			shop_sellSecondaryWeapon();
 			player.weaponType[1] = W_CHARGER;
 
-			while (game.maxRocketAmmo > 5)
-				sell(SHOP_ROCKET_MAX_AMMO);
+			if (game.difficulty != DIFFICULTY_ORIGINAL)
+			{
+				while (game.maxRocketAmmo > 5)
+					sell(SHOP_ROCKET_MAX_AMMO);
+			}
 			while (player.ammo[1] > 0)
 				sell(SHOP_ROCKET_AMMO);
 
@@ -784,7 +819,7 @@ static void buy(int i)
 
 	if (!engine.cheatCash)
 		game.cash -= shopItems[i].price;
-	saveGame(0);
+	save(0);
 }
 
 static void sell(int i)
@@ -792,7 +827,7 @@ static void sell(int i)
 	switch (i)
 	{
 		case SHOP_PLASMA_MAX_OUTPUT:
-			if (game.maxPlasmaOutput <= 1)
+			if (game.maxPlasmaOutput <= ((game.difficulty != DIFFICULTY_ORIGINAL) ? 1 : 2))
 			{
 				shopSelectedItem = -5;
 				return;
@@ -802,14 +837,14 @@ static void sell(int i)
 				sell(SHOP_PLASMA_MIN_OUTPUT);
 
 			game.maxPlasmaOutput--;
-			if (weapon[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput + 1)
-				weapon[W_PLAYER_WEAPON].ammo[0] = MIN(
-					weapon[W_PLAYER_WEAPON].ammo[0],
+			if (weapons[W_PLAYER_WEAPON].ammo[0] <= game.maxPlasmaOutput + 1)
+				weapons[W_PLAYER_WEAPON].ammo[0] = MIN(
+					weapons[W_PLAYER_WEAPON].ammo[0],
 					game.maxPlasmaOutput);
 			break;
 
 		case SHOP_PLASMA_MAX_DAMAGE:
-			if (game.maxPlasmaDamage <= 1)
+			if (game.maxPlasmaDamage <= ((game.difficulty != DIFFICULTY_ORIGINAL) ? 1 : 2))
 			{
 				shopSelectedItem = -5;
 				return;
@@ -819,14 +854,14 @@ static void sell(int i)
 				sell(SHOP_PLASMA_MIN_DAMAGE);
 
 			game.maxPlasmaDamage--;
-			if (weapon[W_PLAYER_WEAPON].damage <= game.maxPlasmaDamage + 1)
-				weapon[W_PLAYER_WEAPON].damage = MIN(
-					weapon[W_PLAYER_WEAPON].damage,
+			if (weapons[W_PLAYER_WEAPON].damage <= game.maxPlasmaDamage + 1)
+				weapons[W_PLAYER_WEAPON].damage = MIN(
+					weapons[W_PLAYER_WEAPON].damage,
 					game.maxPlasmaDamage);
 			break;
 
 		case SHOP_PLASMA_MAX_RATE:
-			if (game.maxPlasmaRate <= 1)
+			if (game.maxPlasmaRate <= ((game.difficulty != DIFFICULTY_ORIGINAL) ? 1 : 2))
 			{
 				shopSelectedItem = -5;
 				return;
@@ -836,9 +871,9 @@ static void sell(int i)
 				sell(SHOP_PLASMA_MIN_RATE);
 
 			game.maxPlasmaRate--;
-			if (weapon[W_PLAYER_WEAPON].reload[0] >= rate2reload[game.maxPlasmaRate + 1])
-				weapon[W_PLAYER_WEAPON].reload[0] = MAX(
-					weapon[W_PLAYER_WEAPON].reload[0],
+			if (weapons[W_PLAYER_WEAPON].reload[0] >= rate2reload[game.maxPlasmaRate + 1])
+				weapons[W_PLAYER_WEAPON].reload[0] = MAX(
+					weapons[W_PLAYER_WEAPON].reload[0],
 					rate2reload[game.maxPlasmaRate]);
 			break;
 
@@ -850,7 +885,7 @@ static void sell(int i)
 			}
 			game.minPlasmaOutput--;
 			if (player.ammo[0] <= 0)
-				weapon[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
+				weapons[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
 			break;
 
 		case SHOP_PLASMA_MIN_DAMAGE:
@@ -861,7 +896,7 @@ static void sell(int i)
 			}
 			game.minPlasmaDamage--;
 			if (player.ammo[0] <= 0)
-				weapon[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
+				weapons[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
 			break;
 
 		case SHOP_PLASMA_MIN_RATE:
@@ -872,7 +907,7 @@ static void sell(int i)
 			}
 			game.minPlasmaRate--;
 			if (player.ammo[0] <= 0)
-				weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
+				weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
 			break;
 
 		case SHOP_PLASMA_AMMO:
@@ -886,9 +921,9 @@ static void sell(int i)
 			else
 			{
 				player.ammo[0] = 0;
-				weapon[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
-				weapon[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
-				weapon[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
+				weapons[W_PLAYER_WEAPON].ammo[0] = game.minPlasmaOutput;
+				weapons[W_PLAYER_WEAPON].damage = game.minPlasmaDamage;
+				weapons[W_PLAYER_WEAPON].reload[0] = rate2reload[game.minPlasmaRate];
 			}
 			break;
 
@@ -1007,27 +1042,31 @@ static void sell(int i)
 	else
 		game.cash += shopItems[i].price;
 
-	saveGame(0);
+	save(0);
 }
 
-void showShop()
+void shop_show()
 {
- 	int icons = SHOP_MAX;
+	int icons = SHOP_MAX;
+	int sell_x = shop_x + shop_w - gfx_sprites[SP_SELL]->w - 2;
+	int sell_y = shop_y + 183;
+	int buy_x = sell_x - gfx_sprites[SP_BUY]->w - 5;
+	int buy_y = shop_y + 183;
 
-	screen_blit(gfx_shopSprites[SHOP_S_PRIMARY], 20, 395);
-	screen_blit(gfx_shopSprites[SHOP_S_POWERUP], 275, 395);
-	screen_blit(gfx_shopSprites[SHOP_S_SECONDARY], 530, 395);
-	screen_blit(gfx_shopSprites[SHOP_S_CATALOG], 100, 180);
-	screen_blit(gfx_shopSprites[SHOP_S_SHIP_INFO], 100, 50);
-	screen_blit(gfx_shopSprites[SHOP_S_ITEM_INFO], 100, 320);
+	screen_blit(gfx_shopSprites[SHOP_S_SHIP_INFO], shop_x, shop_y);
+	screen_blit(gfx_shopSprites[SHOP_S_CATALOG], shop_x, shop_y + 50);
+	screen_blit(gfx_shopSprites[SHOP_S_ITEM_INFO], shop_x, shop_y + 180);
+	screen_blit(gfx_shopSprites[SHOP_S_PRIMARY], shop_x, shop_y + 245);
+	screen_blit(gfx_shopSprites[SHOP_S_POWERUP], shop_x + 203, shop_y + 245);
+	screen_blit(gfx_shopSprites[SHOP_S_SECONDARY], shop_x + 406, shop_y + 245);
 
 	if (shopSelectedItem > -1)
 	{
-		screen_blit(gfx_sprites[SP_BUY], 60, 350);
-		screen_blit(gfx_sprites[SP_SELL], 710, 350);
+		screen_blit(gfx_sprites[SP_BUY], buy_x, buy_y);
+		screen_blit(gfx_sprites[SP_SELL], sell_x, sell_y);
 	}
 
-	screen_blit(gfx_sprites[SP_FIREFLY], 380, 95);
+	screen_blit(gfx_sprites[SP_FIREFLY], shop_x + 280, shop_y + 15);
 
 	if (game.system == 0)
 		icons = SHOP_DOUBLE_ROCKETS + 1;
@@ -1051,14 +1090,14 @@ void showShop()
 
 		if (shopSelectedItem > -1)
 		{
-			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 60, 350, 24, 16))
+			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, buy_x, buy_y, 24, 16))
 			{
 				buy(shopSelectedItem);
 				engine.keyState[KEY_FIRE] = 0;
 				drawShop();
 			}
 
-			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, 700, 350, 24, 16))
+			if (game_collision(engine.cursor_x + 13, engine.cursor_y + 13, 6, 6, sell_x, sell_y, 24, 16))
 			{
 				sell(shopSelectedItem);
 				engine.keyState[KEY_FIRE] = 0;
