@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012, 2013 Guus Sliepen
-Copyright (C) 2012, 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2012, 2015-2017 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,27 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "Starfighter.h"
+#include <stdlib.h>
+#include <stdio.h>
+
+#include "SDL.h"
+
+#include "colors.h"
+#include "defs.h"
+#include "structs.h"
+
+#include "alien.h"
+#include "audio.h"
+#include "engine.h"
+#include "explosion.h"
+#include "game.h"
+#include "gfx.h"
+#include "player.h"
+#include "renderer.h"
+#include "save.h"
+#include "screen.h"
+#include "title.h"
+#include "window.h"
 
 static int showGameMenu(int continueSaveSlot)
 {
@@ -28,21 +48,22 @@ static int showGameMenu(int continueSaveSlot)
 		screen_blitText(TS_CONTINUE_CURRENT_GAME);
 	}
 	screen_blitText(TS_OPTIONS);
+	screen_blitText(TS_CREDITS);
 	if (engine.cheat)
 	{
-		gfx_textSprites[TS_QUIT].y = screen->h / 3 + 150;
+		gfx_textSprites[TS_QUIT].y = screen->h / 3 + 170;
 		screen_blitText(TS_CHEAT_OPTIONS);
 	}
 	else
 	{
-		gfx_textSprites[TS_QUIT].y = screen->h / 3 + 130;
+		gfx_textSprites[TS_QUIT].y = screen->h / 3 + 150;
 	}
 	screen_blitText(TS_QUIT);
 
 	if (engine.cheat)
-		return 6;
+		return 7;
 
-	return 5;
+	return 6;
 }
 
 static int showLoadMenu()
@@ -188,7 +209,7 @@ static int showCheatMenu()
 This is the main title screen, with the stars whirling past and the
 "Parallel Realities, Present..." text. Nothing too special.
 */
-int doTitle()
+int title_show()
 {
 	int continueSaveSlot;
 
@@ -205,8 +226,8 @@ int doTitle()
 	char buildVersion[25];
 
 	int selectedOption = 1;
-	bool skip = false;
-	int listLength = 5; // menu list length
+	int skip = 0;
+	int listLength = 6; // menu list length
 	int menuType = MENU_MAIN;
 
 	game_init();
@@ -215,21 +236,21 @@ int doTitle()
 
 	screen_flushBuffer();
 	gfx_free();
-	resetLists();
+	engine_resetLists();
 	
 	// required to stop the title screen crashing
 	game.system = 0;
 	game.area = MISN_START;
 
-	loadGameGraphics();
+	gfx_loadSprites();
 
 	screen_clear(black);
 	renderer_update();
 	screen_clear(black);
 
-	continueSaveSlot = initSaveSlots();
+	continueSaveSlot = save_initSlots();
 
-	loadBackground("gfx/spirit.jpg");
+	gfx_loadBackground("gfx/spirit.jpg");
 
 	SDL_Surface *prlogo, *sflogo;
 	prlogo = gfx_loadImage("gfx/prlogo.png");
@@ -253,10 +274,12 @@ int doTitle()
 		-1, screen->h / 3 + 90, FONT_WHITE);
 	gfx_createTextObject(TS_OPTIONS, "OPTIONS",
 		-1, screen->h / 3 + 110, FONT_WHITE);
+	gfx_createTextObject(TS_CREDITS, "CREDITS",
+		-1, screen->h / 3 + 130, FONT_WHITE);
 	gfx_createTextObject(TS_CHEAT_OPTIONS, "CHEAT OPTIONS",
-		-1, screen->h / 3 + 130, FONT_WHITE);
+		-1, screen->h / 3 + 150, FONT_WHITE);
 	gfx_createTextObject(TS_QUIT, "QUIT",
-		-1, screen->h / 3 + 130, FONT_WHITE);
+		-1, screen->h / 3 + 150, FONT_WHITE);
 
 	createOptionsMenu();
 	createDifficultyMenu();
@@ -303,7 +326,7 @@ int doTitle()
 	screen_drawBackground();
 
 	engine.done = 0;
-	flushInput();
+	player_flushInput();
 	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
 
 	audio_playMusic("music/walking_among_androids.ogg", 1);
@@ -403,27 +426,20 @@ int doTitle()
 				if (!skip)
 				{
 					gfx_renderString("Copyright Parallel Realities 2003",
-						5, screen->h - 60, FONT_WHITE, 0, gfx_background);
+						5, gfx_background->h - 60, FONT_WHITE, 0, gfx_background);
 					gfx_renderString("Copyright Guus Sliepen, Astrid S. de Wijn and others 2012",
-						5, screen->h - 40, FONT_WHITE, 0, gfx_background);
-					gfx_renderString("Copyright 2015, 2016 onpon4",
-						5, screen->h - 20, FONT_WHITE, 0, gfx_background);
-					gfx_renderString(buildVersion, screen->w - 6 - strlen(buildVersion) * 9,
-						screen->h - 20, FONT_WHITE, 0, gfx_background);
+						5, gfx_background->h - 40, FONT_WHITE, 0, gfx_background);
+					gfx_renderString("Copyright 2015-2017 Julie Marchant",
+						5, gfx_background->h - 20, FONT_WHITE, 0, gfx_background);
+					gfx_renderString(buildVersion, gfx_background->w - 6 - strlen(buildVersion) * 9,
+						gfx_background->h - 20, FONT_WHITE, 0, gfx_background);
 					screen_addBuffer(0, 0, screen->w, screen->h);
-					skip = true;
+					skip = 1;
 				}
 			}
 		}
 
-		getPlayerInput();
-
-		// if someone has invoked the credits cheat
-		if (engine.cheatCredits)
-		{
-			doCredits();
-			engine.cheatCredits = false;
-		}
+		player_getInput();
 
 		if ((engine.keyState[KEY_FIRE] || engine.keyState[KEY_ALTFIRE]))
 		{
@@ -433,12 +449,12 @@ int doTitle()
 					5, screen->h - 60, FONT_WHITE, 0, gfx_background);
 				gfx_renderString("Copyright Guus Sliepen, Astrid S. de Wijn and others 2012",
 					5, screen->h - 40, FONT_WHITE, 0, gfx_background);
-				gfx_renderString("Copyright 2015, 2016 onpon4",
+				gfx_renderString("Copyright 2015-2017 Julie Marchant",
 					5, screen->h - 20, FONT_WHITE, 0, gfx_background);
 				gfx_renderString(buildVersion, screen->w - 6 - strlen(buildVersion) * 9,
 					screen->h - 20, FONT_WHITE, 0, gfx_background);
-				screen_addBuffer(0, 560, 800, 40);
-				skip = true;
+				screen_addBuffer(0, screen->h - 40, screen->w, 40);
+				skip = 1;
 			}
 			else
 			{
@@ -460,9 +476,13 @@ int doTitle()
 						else if (selectedOption == 4)
 						{
 							menuType = MENU_OPTIONS;
-							selectedOption = 1;
+							selectedOption = 5;
 						}
 						else if (selectedOption == 5)
+						{
+							engine.done = 1;
+						}
+						else if (selectedOption == 6)
 						{
 							if (engine.cheat)
 							{
@@ -472,7 +492,7 @@ int doTitle()
 							else
 								engine.done = 1;
 						}
-						else if (selectedOption == 6)
+						else if (selectedOption == 7)
 							engine.done = 1;
 						break;
 
@@ -508,7 +528,10 @@ int doTitle()
 
 					case MENU_OPTIONS:
 						if ((selectedOption == 1) && (engine.useAudio))
+						{
 							engine.useSound = !engine.useSound;
+							selectedOption = listLength;
+						}
 						else if ((selectedOption == 2) && (engine.useAudio))
 						{
 							engine.useMusic = !engine.useMusic;
@@ -522,22 +545,24 @@ int doTitle()
 							{
 								audio_haltMusic();
 							}
+							selectedOption = listLength;
 						}
 						else if (selectedOption == 3)
 						{
 							engine.fullScreen = !engine.fullScreen;
 							SDL_SetWindowFullscreen(window,
-								(engine.fullScreen ?
-									SDL_WINDOW_FULLSCREEN_DESKTOP : 0));
+								(engine.fullScreen ? FULLSCREEN : 0));
+							selectedOption = listLength;
 						}
 						else if (selectedOption == 4)
 						{
 							engine.autoPause = !engine.autoPause;
+							selectedOption = listLength;
 						}
 						else if (selectedOption == listLength)
 						{
 							menuType = MENU_MAIN;
-							selectedOption = 1;
+							selectedOption = 4;
 						}
 						createOptionsMenu();
 						break;
@@ -565,7 +590,8 @@ int doTitle()
 						break;
 				}
 			}
-			engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
+			engine.keyState[KEY_FIRE] = 0;
+			engine.keyState[KEY_ALTFIRE] = 0;
 		}
 
 		game_delayFrame();
@@ -576,9 +602,10 @@ int doTitle()
 	SDL_FreeSurface(prlogo);
 	SDL_FreeSurface(sflogo);
 
-	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
+	engine.keyState[KEY_FIRE] = 0;
+	engine.keyState[KEY_ALTFIRE] = 0;
 
-	resetLists();
+	engine_resetLists();
 
 	if (selectedOption == 1)
 	{
@@ -589,11 +616,17 @@ int doTitle()
 	if (selectedOption == 3)
 	{
 		game_init();
-		selectedOption = loadGame(continueSaveSlot);
+		selectedOption = save_load(continueSaveSlot);
+	}
+
+	if (selectedOption == 5)
+	{
+		title_showCredits();
+		selectedOption = 0;
 	}
 
 	// Send back a negative number...
-	if (selectedOption > 4)
+	if (selectedOption > 5)
 	{
 		selectedOption = -1;
 		exit(0);
@@ -602,124 +635,9 @@ int doTitle()
 	return selectedOption;
 }
 
-/*
-Scrolls the intro text up the screen and nothing else.
-*/
-void showStory()
+void title_showCredits()
 {
-	gfx_free();
-
-	int y = screen->h + 20;
-
-	FILE *fp;
-
-	fp = fopen("data/intro.txt", "rb");
-
-	int index = 0;
-	int nextPos = -1;
-	char string[255];
-
-	while (fscanf(fp, "%d %[^\n]%*c", &nextPos, string) == 2)
-	{
-		y += nextPos;
-		gfx_createTextObject(index, string, -1, y, FONT_WHITE);
-
-		index++;
-	}
-
-	fclose(fp);
-
-	loadBackground("gfx/startUp.jpg");
-	screen_drawBackground();
-	screen_flushBuffer();
-
-	flushInput();
-	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
-
-	while (true)
-	{
-		renderer_update();
-		screen_unBuffer();
-
-		getPlayerInput();
-
-		if ((engine.keyState[KEY_FIRE] || engine.keyState[KEY_ALTFIRE]))
-			break;
-
-		// XXX: The fact that it's line 8 that's watched is completely
-		// arbitrary. It might be prudent to replace this with something else.
-		if (gfx_textSprites[8].y > (screen->h / 2) + 150)
-		{
-			for (int i = 0 ; i < 9 ; i++)
-			{
-				gfx_textSprites[i].y -= 0.33333;
-				screen_blitText(i);
-			}
-		}
-		else
-		{
-			SDL_Delay(3000);
-			break;
-		}
-
-		game_delayFrame();
-	}
-}
-
-/*
-The game over screen :(
-*/
-void gameover()
-{
-	screen_flushBuffer();
-	gfx_free();
-	SDL_FillRect(gfx_background, NULL, black);
-
-	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
-	engine.gameSection = SECTION_INTERMISSION;
-
-	SDL_Surface *gameover = gfx_loadImage("gfx/gameover.png");
-
-	screen_clear(black);
-	renderer_update();
-	screen_clear(black);
-	SDL_Delay(1000);
-
-	audio_playMusic("music/death.ogg", -1);
-
-	int x = (screen->w - gameover->w) / 2;
-	int y = (screen->h - gameover->h) / 2;
-
-	renderer_update();
-
-	flushInput();
-	engine.keyState[KEY_FIRE] = engine.keyState[KEY_ALTFIRE] = 0;
-
-	while (true)
-	{
-		getPlayerInput();
-
-		if (engine.keyState[KEY_FIRE] || engine.keyState[KEY_ALTFIRE])
-			break;
-
-		renderer_update();
-
-		screen_unBuffer();
-		x = ((screen->w - gameover->w) / 2) - RANDRANGE(-2, 2);
-		y = ((screen->h - gameover->h) / 2)  - RANDRANGE(-2, 2);
-		screen_blit(gameover, x,  y);
-
-		game_delayFrame();
-	}
-
-	SDL_FreeSurface(gameover);
-	audio_haltMusic();
-	screen_flushBuffer();
-}
-
-void doCredits()
-{
-	loadBackground("gfx/credits.jpg");
+	gfx_loadBackground("gfx/credits.jpg");
 	screen_flushBuffer();
 	gfx_free();
 
@@ -731,7 +649,7 @@ void doCredits()
 	char text[255];
 	int i;
 
-	textObject *credit;
+	TextObject *credit;
 
 	screen_clear(black);
 	renderer_update();
@@ -745,7 +663,7 @@ void doCredits()
 	// FIXME: It would be nice for the size of this array to be determined
 	// by the number of lines in the text file. I'm not sure how to do
 	// that at the moment, so just giving it a very large number for now.
-	credit = (textObject*) malloc(sizeof(textObject) * 300);
+	credit = (TextObject*) malloc(sizeof(TextObject) * 300);
 
 	while (fscanf(fp, "%d %[^\n]%*c", &yPos, text) == 2)
 	{
@@ -763,14 +681,14 @@ void doCredits()
 	engine.keyState[KEY_ESCAPE] = 0;
 	engine.keyState[KEY_FIRE] = 0;
 	engine.keyState[KEY_ALTFIRE] = 0;
-	flushInput();
+	player_flushInput();
 
-	while (true)
+	while (1)
 	{
 		renderer_update();
 		screen_unBuffer();
 
-		getPlayerInput();
+		player_getInput();
 		if (engine.keyState[KEY_ESCAPE] || engine.keyState[KEY_FIRE] ||
 				engine.keyState[KEY_ALTFIRE])
 			break;
