@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
+Copyright (C) 2015, 2016 Julie Marchant <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,8 +20,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef WEAPONS_H
 #define WEAPONS_H
 
-extern object weapon[W_MAX];
+#include "defs.h"
+#include "structs.h"
 
-extern void initWeapons();
+extern Object weapons[W_MAX];
+
+void weapons_init();
 
 #endif
